@@ -16,5 +16,9 @@
 // Import commands.js using ES2015 syntax:
 import './commands.js'
 
+Cypress.on('uncaught:exception', (err) => {
+	return !err.message.includes('ResizeObserver loop limit exceeded')
+})
+
 // Alternatively you can use CommonJS syntax:
 // require('./commands')
