@@ -2,6 +2,7 @@ OC.L10N.register(
     "deck",
     {
     "Personal" : "Persoonlik",
+    "Later" : "Later",
     "copy" : "kopie",
     "Done" : "Gereed",
     "The file was uploaded" : "Die lêer is opgelaai",
@@ -12,7 +13,6 @@ OC.L10N.register(
     "Missing a temporary folder" : "Ontbrekende tydelike gids",
     "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
     "Cancel" : "Kanselleer",
-    "Close" : "Sluit",
     "File already exists" : "Lêer bestaan reeds",
     "Open details" : "Open besonderhede",
     "Details" : "Besonderhede",
@@ -27,18 +27,21 @@ OC.L10N.register(
     "Comments" : "Kommentare",
     "Modified" : "Gewysig",
     "Created" : "Geskep",
-    "Due date" : "Sperdatum",
-    "Select Date" : "Kies Datum",
-    "Today" : "Vandag",
-    "Tomorrow" : "Môre",
     "Save" : "Stoor",
     "Reply" : "Antwoord",
     "Update" : "Werk by",
+    "Created:" : "Geskep:",
     "Description" : "Beskrywing",
+    "Completed" : "Voltooid",
+    "Select Date" : "Kies Datum",
     "seconds ago" : "sekondes gelede",
     "Shared with you" : "Met u gedeel",
     "No notifications" : "Geen kennisgewings",
     "An error occurred" : "'n Fout het voorgekom",
-    "Share" : "Deel"
+    "Today" : "Vandag",
+    "Tomorrow" : "Môre",
+    "Close" : "Sluit",
+    "Share" : "Deel",
+    "Due date" : "Sperdatum"
 },
 "nplurals=2; plural=(n != 1);");
