@@ -2,14 +2,15 @@ OC.L10N.register(
     "deck",
     {
     "Personal" : "Personol",
+    "%s on %s" : "%s ar %s",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
     "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
     "Missing a temporary folder" : "Plygell dros dro yn eisiau",
     "Cancel" : "Diddymu",
-    "Close" : "Cau",
     "Details" : "Manylion",
     "Tags" : "Tagiau",
+    "Activity" : "Gweithred",
     "Undo" : "Dadwneud",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
@@ -18,17 +19,19 @@ OC.L10N.register(
     "Edit" : "Golygu",
     "Download" : "Llwytho i lawr",
     "Modified" : "Addaswyd",
-    "Select Date" : "Dewis Dyddiad",
-    "Today" : "Heddiw",
-    "Next week" : "Wythnos nesaf",
-    "Next month" : "Mis nesaf",
     "Save" : "Cadw",
     "Update" : "Diweddaru",
+    "Created:" : "Crewyd:",
     "Description" : "Disgrifiad",
+    "Select Date" : "Dewis Dyddiad",
     "seconds ago" : "eiliad yn ôl",
     "Shared with you" : "Shared with you",
     "No reminder" : "Dim nodyn atgoffa",
     "An error occurred" : "Digwyddodd gwall",
-    "Share" : "Rhannu"
+    "Today" : "Heddiw",
+    "Close" : "Cau",
+    "Share" : "Rhannu",
+    "Next week" : "Wythnos nesaf",
+    "Next month" : "Mis nesaf"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
