@@ -68,11 +68,8 @@ OC.L10N.register(
     "Search by board title" : "Søg efter tavle titel",
     "Select board" : "Vælg tavle",
     "Select a board" : "Vælg én tavle",
-    "Select a list" : "Vælg en kolonne",
-    "Cancel" : "Annullér",
-    "Close" : "Luk",
-    "Create card" : "Opret kort",
     "Select a card" : "Vælg et kort",
+    "Cancel" : "Annullér",
     "Select the card to link to a project" : "Vælg et kort at linke til et projekt",
     "Link to card" : "Link til kort",
     "File already exists" : "Filen findes allerede",
@@ -109,7 +106,7 @@ OC.L10N.register(
     "Sharing" : "Deling",
     "Tags" : "Mærkat",
     "Deleted items" : "Slettede objekter",
-    "Timeline" : "Tidslinje",
+    "Activity" : "Aktivitet",
     "Deleted lists" : "Slettede kolonner",
     "Undo" : "Fortryd",
     "Deleted cards" : "Sletttede kort",
@@ -137,6 +134,8 @@ OC.L10N.register(
     "title and color value must be provided" : "Titel og farve skal angives.",
     "Board name" : "Tavle navn",
     "Members" : "Medlemmer",
+    "Assign to users/groups/circles" : "Tildel til brugere/grupper/cirkler",
+    "Assign a user to this card…" : "Tildel en bruger til dette kort",
     "Upload new files" : "Upload nye filer",
     "Share from Files" : "Del fra Filer",
     "Add this attachment" : "Tilføj denne vedhæftning",
@@ -154,24 +153,13 @@ OC.L10N.register(
     "Created" : "Oprettet",
     "The title cannot be empty." : "Titlen kan ikke være tom",
     "No comments yet. Begin the discussion!" : "Ingen kommentarer endnu. Begynd diskussionen!",
-    "Assign a tag to this card…" : "Tilføj et mærkat til dette kort ...",
-    "Assign to users" : "Tildel til brugere",
-    "Assign to users/groups/circles" : "Tildel til brugere/grupper/cirkler",
-    "Assign a user to this card…" : "Tildel en bruger til dette kort",
-    "Due date" : "Forfaldsdato",
-    "Set a due date" : "Sæt en forfaldsdato",
-    "Remove due date" : "Fjern forfaldsdato",
-    "Select Date" : "Vælg dato",
-    "Today" : "I dag",
-    "Tomorrow" : "I morgen",
-    "Next week" : "Næste uge",
-    "Next month" : "Næste måned",
     "Save" : "Gem",
     "The comment cannot be empty." : "Kommentaren kan ikke være tom.",
     "The comment cannot be longer than 1000 characters." : "Kommentaren kan ikke være længere end 1000 tegn.",
     "In reply to" : "som svar til",
     "Reply" : "Besvar",
     "Update" : "Opdatér",
+    "Created:" : "Oprettet:",
     "Description" : "Beskrivelse",
     "(Unsaved)" : "(Ikke gemt)",
     "(Saving…)" : "(Gemmer...)",
@@ -181,24 +169,30 @@ OC.L10N.register(
     "Add Attachment" : "Tilføj vedhæftning",
     "Write a description …" : "Tilføj en beskrivelse...",
     "Choose attachment" : "Vælg en vedhæftning",
-    "(group)" : "(gruppe)",
-    "Assign to me" : "Tildel til mig",
-    "Unassign myself" : "Fjern mig selv",
-    "Move card" : "Flyt kort",
-    "Card details" : "Kort detaljer",
+    "Set a due date" : "Sæt en forfaldsdato",
+    "Remove due date" : "Fjern forfaldsdato",
+    "Completed" : "Fuldført",
+    "Not completed" : "Ikke afsluttet",
     "Unarchive card" : "Gen-aktivér kort",
     "Archive card" : "Arkivér kort",
+    "Select Date" : "Vælg dato",
+    "Assign a tag to this card…" : "Tilføj et mærkat til dette kort ...",
+    "(group)" : "(gruppe)",
+    "Card details" : "Kort detaljer",
+    "Assign to me" : "Tildel til mig",
+    "Unassign myself" : "Fjern mig selv",
+    "Mark as done" : "Marker som færdig",
+    "Move card" : "Flyt kort",
     "Delete card" : "Slet kort",
     "Move card to another board" : "Flyt kort til en anden tavle",
+    "Select a list" : "Vælg en kolonne",
     "Card deleted" : "Kort slettet",
-    "seconds ago" : "sekunder siden",
+    "seconds ago" : "få sekunder siden",
     "All boards" : "Alle tavler",
     "Archived boards" : "Arkiverede lister",
     "Shared with you" : "Shared with you",
     "Use bigger card view" : "Brug større kort visning",
     "Show boards in calendar/tasks" : "Vis tavler i kalender/opgaver",
-    "Limit deck usage of groups" : "Begræns Deck brug til grupper",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begrænsning af Deck vil blokere brugere som ikke er en del af de valgte grupper fra at oprette deres egne tavler. Brugere vil stadig kunne arbejde på tavler der er blevet delt med dem. ",
     "Board details" : "Liste detaljer",
     "Edit board" : "Rediger liste",
     "Clone board" : "Klon tavle",
@@ -217,7 +211,11 @@ OC.L10N.register(
     "An error occurred" : "Der var en fejl",
     "Delete the board?" : "Slet tavlen?",
     "Loading filtered view" : "Indlæser filtreret visning",
+    "Today" : "I dag",
+    "Tomorrow" : "I morgen",
     "No due" : "Ikke forfalden",
+    "Create card" : "Opret kort",
+    "Close" : "Luk",
     "No upcoming cards" : "Ingen kommende kort",
     "upcoming cards" : "kommende kort",
     "Link to a board" : "Link til tavle",
@@ -230,6 +228,13 @@ OC.L10N.register(
     "Share with a Deck card" : "Del med et Deck kort",
     "Share {file} with a Deck card" : "Del {file} med et Deck kort",
     "Share" : "Del",
-    "Add a new list" : "Tilføj en ny kolonne"
+    "Timeline" : "Tidslinje",
+    "Add a new list" : "Tilføj en ny kolonne",
+    "Assign to users" : "Tildel til brugere",
+    "Due date" : "Forfaldsdato",
+    "Next week" : "Næste uge",
+    "Next month" : "Næste måned",
+    "Limit deck usage of groups" : "Begræns Deck brug til grupper",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begrænsning af Deck vil blokere brugere som ikke er en del af de valgte grupper fra at oprette deres egne tavler. Brugere vil stadig kunne arbejde på tavler der er blevet delt med dem. "
 },
 "nplurals=2; plural=(n != 1);");
