@@ -39,7 +39,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} restaŭris la dosieron {attachment} al karto {card}",
     "You have commented on card {card}" : "Vi komentis la karton {card}",
     "{user} has commented on card {card}" : "{user} komentis la karton {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Karta priskribo</strong> ene de la aplikaĵo Kartaro ŝanĝiĝis",
     "Deck" : "Kartaro",
     "Changes in the <strong>Deck app</strong>" : "Ŝanĝoj en la <strong>aplikaĵo Kartaro</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Komento</strong> kreiĝis sur karton",
@@ -74,7 +73,6 @@ OC.L10N.register(
     "Select the board to link to a project" : "Elekti la tabulon ligotan al projekto",
     "Select board" : "Elekti tabulon",
     "Cancel" : "Nuligi",
-    "Close" : "Malfermi",
     "File already exists" : "La dosiero jam ekzistas",
     "Add card" : "Aldoni karton",
     "Archived cards" : "Arĥivigitaj kartoj",
@@ -86,7 +84,7 @@ OC.L10N.register(
     "Sharing" : "Kunhavigo",
     "Tags" : "Etikedoj",
     "Deleted items" : "Forigitaj elementoj",
-    "Timeline" : "Kronologio",
+    "Activity" : "Aktivaĵoj",
     "Undo" : "Malfari",
     "Deleted cards" : "Forigitaj kartoj",
     "(Group)" : "(grupo)",
@@ -101,33 +99,38 @@ OC.L10N.register(
     "Comments" : "Komentoj",
     "Modified" : "Modifita",
     "Created" : "Kreita",
-    "Due date" : "Limdato",
-    "Remove due date" : "Viŝi limdaton",
-    "Select Date" : "Elekti daton",
-    "Today" : "Hodiaŭ",
-    "Tomorrow" : "Morgaŭ",
     "Save" : "Konservi",
     "Reply" : "Respondi",
     "Update" : "Ĝisdatigi",
+    "Created:" : "Kreita:",
     "Description" : "Priskribo",
     "Formatting help" : "Helpo pri tekstaranĝo",
-    "(group)" : "(grupo)",
+    "Remove due date" : "Viŝi limdaton",
+    "Completed" : "Plenumita",
     "Unarchive card" : "Malarĥivigi karton",
     "Archive card" : "Arĥivigi karton",
+    "Select Date" : "Elekti daton",
+    "(group)" : "(grupo)",
     "Delete card" : "Forigi karton",
     "seconds ago" : "antaŭ kelkaj sekundoj",
     "Archived boards" : "Arĥivigitaj tabuloj",
     "Shared with you" : "Kunhavata kun vi",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limigo de Kartaro („Deck“) baros uzantojn, kiuj ne estas en tiuj grupoj, krei iliajn proprajn tabulojn. Uzantoj tamen eblos labori kun tabuloj kunhavigitaj kun ili.",
     "Edit board" : "Modifi tabulon",
     "Unarchive board" : "Elarĥivigi tabulon",
     "Archive board" : "Enarĥivigi tabulon",
     "No notifications" : "Neniu sciigo",
     "Delete board" : "Forigi tabulon",
     "An error occurred" : "Eraro okazis",
+    "Today" : "Hodiaŭ",
+    "Tomorrow" : "Morgaŭ",
+    "Close" : "Malfermi",
     "Link to a board" : "Ligilo al tabulo",
     "Maximum file size of {size} exceeded" : "Maksimuma dosiergrando {size} transpasita",
     "Error creating the share" : "Eraro dum kreo de la kunhavigo",
-    "Share" : "Kunhavigi"
+    "Share" : "Kunhavigi",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Karta priskribo</strong> ene de la aplikaĵo Kartaro ŝanĝiĝis",
+    "Timeline" : "Kronologio",
+    "Due date" : "Limdato",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limigo de Kartaro („Deck“) baros uzantojn, kiuj ne estas en tiuj grupoj, krei iliajn proprajn tabulojn. Uzantoj tamen eblos labori kun tabuloj kunhavigitaj kun ili."
 },
 "nplurals=2; plural=(n != 1);");
