@@ -17,7 +17,6 @@ OC.L10N.register(
     "Missing a temporary folder" : "Falta una carpeta temporal",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Cancel" : "Cancelar",
-    "Close" : "Cerrar",
     "File already exists" : "El archivo ya existe",
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
     "Add card" : "Agregar tarjeta",
@@ -27,6 +26,7 @@ OC.L10N.register(
     "Details" : "Detalles",
     "Sharing" : "Compartiendo",
     "Tags" : "Etiquetas",
+    "Activity" : "Actividad",
     "Undo" : "Deshacer",
     "Can edit" : "Puede editar",
     "Can share" : "Puede compartir",
@@ -38,15 +38,14 @@ OC.L10N.register(
     "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
-    "Due date" : "Fecha de vencimiento",
-    "Remove due date" : "Eliminar fecha de expiración",
-    "Today" : "Hoy",
-    "Tomorrow" : "Mañana",
     "Save" : "Guardar",
     "Reply" : "Responder",
     "Update" : "Actualizar",
+    "Created:" : "Creado:",
     "Description" : "Descripción",
     "Formatting help" : "Ayuda de formato",
+    "Remove due date" : "Eliminar fecha de expiración",
+    "Completed" : "Completado",
     "(group)" : "(grupo)",
     "seconds ago" : "hace segundos",
     "Archived boards" : "Tableros archivados",
@@ -57,6 +56,10 @@ OC.L10N.register(
     "Archive board" : "Archivar tablero",
     "No notifications" : "No hay notificaciones",
     "Delete board" : "Borrar tableros",
-    "Share" : "Compartir"
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana",
+    "Close" : "Cerrar",
+    "Share" : "Compartir",
+    "Due date" : "Fecha de vencimiento"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
