@@ -4,6 +4,7 @@ OC.L10N.register(
     "Personal" : "Isiklik",
     "Finished" : "Lõpetatud",
     "Later" : "Hiljem",
+    "copy" : "koopia",
     "Done" : "Valmis",
     "The file was uploaded" : "Fail laaditi üles",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
@@ -12,13 +13,15 @@ OC.L10N.register(
     "No file was uploaded" : "Ühtegi faili ei latud üles",
     "Missing a temporary folder" : "Ajutine kausta on puudu",
     "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
+    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
+    "No file uploaded or file size exceeds maximum of %s" : "Faili ei laaditud üles või selle suurus ületab maksimaalse %s",
     "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
     "Cancel" : "Loobu",
-    "Close" : "Sulge",
     "File already exists" : "Fail on juba olemas",
     "Details" : "Üksikasjad",
     "Sharing" : "Jagamine",
     "Tags" : "Sildid",
+    "Activity" : "Tegevus",
     "Undo" : "Tühista",
     "Can edit" : "Võib redigeerida",
     "Can share" : "Can share",
@@ -29,21 +32,25 @@ OC.L10N.register(
     "Comments" : "Kommentaarid",
     "Modified" : "Muudetud",
     "Created" : "Loodud",
-    "Due date" : "Tähtaeg",
-    "Today" : "Täna",
-    "Tomorrow" : "Homme",
-    "Next week" : "Järgmine nädal",
-    "Next month" : "Järgmine kuu",
     "Save" : "Salvesta",
     "Reply" : "Vasta",
     "Update" : "Uuenda",
+    "Created:" : "Loodud:",
     "Description" : "Kirjeldus",
+    "Completed" : "Lõpetatud",
     "(group)" : "(grupp)",
     "Delete card" : "Kustuta kaart",
     "seconds ago" : "sekundit tagasi",
     "Shared with you" : "Sinuga jagatud",
     "No notifications" : "Märguandeid pole",
     "An error occurred" : "Tekkis tõrge",
-    "Share" : "Jaga"
+    "Today" : "Täna",
+    "Tomorrow" : "Homme",
+    "Close" : "Sulge",
+    "Share" : "Jaga",
+    "Timeline" : "Ajajoon",
+    "Due date" : "Tähtaeg",
+    "Next week" : "Järgmine nädal",
+    "Next month" : "Järgmine kuu"
 },
 "nplurals=2; plural=(n != 1);");
