@@ -51,7 +51,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} palautti liitteen {attachment} kortille {card}",
     "You have commented on card {card}" : "Kommentoit korttia {card}",
     "{user} has commented on card {card}" : "{user} kommentoi korttia {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Kortin kuvaus</strong> Pakka-sovelluksessa on vaihtunut",
     "Deck" : "Pakka",
     "Changes in the <strong>Deck app</strong>" : "Muutokset <strong>Pakka-sovelluksessa</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Kommentti</strong> luotiin kortille",
@@ -91,17 +90,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Valitse projektiin linkitettävä taulu",
     "Search by board title" : "Hae taulun otsikon mukaan",
     "Select board" : "Valitse taulu",
-    "Create a new card" : "Luo uusi kortti",
     "Select a board" : "Valitse taulu",
-    "Select a list" : "Valitse lista ",
-    "Card title" : "Kortin otsikko",
-    "Cancel" : "Peruuta",
-    "Creating the new card …" : "Luodaan uutta korttia…",
-    "Card \"{card}\" was added to \"{board}\"" : "Kortti \"{card}\" lisättiin taululle \"{board}\"",
-    "Open card" : "Avaa kortti",
-    "Close" : "Sulje",
-    "Create card" : "Luo kortti",
     "Select a card" : "Valitse kortti",
+    "Cancel" : "Peruuta",
     "Select the card to link to a project" : "Valitse projektiin linkitettävä kortti",
     "Link to card" : "Linkitä korttiin",
     "File already exists" : "Tiedosto on jo olemassa",
@@ -138,7 +129,7 @@ OC.L10N.register(
     "Sharing" : "Jakaminen",
     "Tags" : "Tunnisteet",
     "Deleted items" : "Poistetut tietueet",
-    "Timeline" : "Aikajana",
+    "Activity" : "Tapahtumat",
     "Deleted lists" : "Poistetut listat",
     "Undo" : "Kumoa",
     "Deleted cards" : "Poistetut kortit",
@@ -180,15 +171,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Otsikko ei voi olla tyhjä.",
     "No comments yet. Begin the discussion!" : "Ei vielä kommentteja. Aloita keskustelu!",
     "Failed to load comments" : "Kommenttien lataaminen epäonnistui",
-    "Assign a tag to this card…" : "Lisää kortille tunniste...",
-    "Due date" : "Eräpäivä",
-    "Set a due date" : "Aseta eräpäivä",
-    "Remove due date" : "Poista eräpäivä",
-    "Select Date" : "Valitse päivä",
-    "Today" : "Tänään",
-    "Tomorrow" : "Huomenna",
-    "Next week" : "Seuraava viikko",
-    "Next month" : "Seuraava kuukausi",
     "Save" : "Tallenna",
     "The comment cannot be empty." : "Kommentti ei voi olla tyhjä.",
     "The comment cannot be longer than 1000 characters." : "Kommentin on oltava alle 1000 merkkiä pitkä.",
@@ -196,6 +178,7 @@ OC.L10N.register(
     "Cancel reply" : "Peru vastaus",
     "Reply" : "Vastaa",
     "Update" : "Päivitä",
+    "Created:" : "Luotu:",
     "Description" : "Kuvaus",
     "(Unsaved)" : "(Tallentamaton)",
     "(Saving…)" : "(Tallennetaan…)",
@@ -205,23 +188,31 @@ OC.L10N.register(
     "Add Attachment" : "Lisää liite",
     "Write a description …" : "Kirjoita kuvaus…",
     "Choose attachment" : "Valitse liite",
-    "(group)" : "(ryhmä)",
-    "{count} comments, {unread} unread" : "{count} kommenttia, {unread} lukematonta",
-    "Assign to me" : "Määritä minulle",
-    "Unassign myself" : "Poista määritys minulta",
-    "Move card" : "Siirrä kortti",
-    "Card details" : "Näytä kortin sisältö",
+    "Set a due date" : "Aseta eräpäivä",
+    "Remove due date" : "Poista eräpäivä",
+    "Completed" : "Valmistui",
+    "Not completed" : "Ei valmis",
     "Unarchive card" : "Poista kortti arkistosta",
     "Archive card" : "Arkistoi kortti",
+    "Select Date" : "Valitse päivä",
+    "Assign a tag to this card…" : "Lisää kortille tunniste...",
+    "(group)" : "(ryhmä)",
+    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
+    "{count} comments, {unread} unread" : "{count} kommenttia, {unread} lukematonta",
+    "Card details" : "Näytä kortin sisältö",
+    "Assign to me" : "Määritä minulle",
+    "Unassign myself" : "Poista määritys minulta",
+    "Mark as done" : "Merkitse valmiiksi",
+    "Move card" : "Siirrä kortti",
     "Delete card" : "Poista kortti",
     "Move card to another board" : "Siirrä kortti toiselle taululle",
+    "Select a list" : "Valitse lista ",
     "List is empty" : "Lista on tyhjä",
     "Card deleted" : "Kortti poistettu",
     "seconds ago" : "sekuntia sitten",
     "All boards" : "Kaikki taulut",
     "Archived boards" : "Arkistoidut taulut",
     "Shared with you" : "Jaettu kanssasi",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Pakan käytön rajoittaminen estää merkittyjen ryhmien jäseniä luomasta omia taulujaan, mutta käyttäjät pystyvät silti käyttämään heidän kanssaan jaettuja tauluja.",
     "Board details" : "Taulun tiedot",
     "Edit board" : "Muokkaa taulua",
     "Clone board" : "Monista taulu",
@@ -234,11 +225,23 @@ OC.L10N.register(
     "No reminder" : "Ei muistutusta",
     "An error occurred" : "Tapahtui virhe",
     "Delete the board?" : "Poistetaanko tämä taulu?",
+    "Today" : "Tänään",
+    "Tomorrow" : "Huomenna",
     "Search for {searchQuery} in all boards" : "Hae ehtoja {searchQuery} kaikilta tauluilta",
     "No results found" : "Ei tuloksia",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
     "Click to expand comment" : "Napsauta laajentaaksesi kommentin",
+    "Create a new card" : "Luo uusi kortti",
+    "Card title" : "Kortin otsikko",
+    "Create card" : "Luo kortti",
+    "Creating the new card …" : "Luodaan uutta korttia…",
+    "Card \"{card}\" was added to \"{board}\"" : "Kortti \"{card}\" lisättiin taululle \"{board}\"",
+    "Open card" : "Avaa kortti",
+    "Close" : "Sulje",
     "No upcoming cards" : "Ei tulevia kortteja",
     "upcoming cards" : "tulevat kortit",
+    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
+    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Link to a board" : "Linkki taululle",
     "Link to a card" : "Linkitä korttiin",
     "Create a card" : "Luo kortti",
@@ -247,6 +250,12 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Tiedoston enimmäiskoko {size} ylitetty",
     "Error creating the share" : "Virhe jakoa luotaessa",
     "Share" : "Jaa",
-    "Add a new list" : "Lisää uusi lista"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Kortin kuvaus</strong> Pakka-sovelluksessa on vaihtunut",
+    "Timeline" : "Aikajana",
+    "Add a new list" : "Lisää uusi lista",
+    "Due date" : "Eräpäivä",
+    "Next week" : "Seuraava viikko",
+    "Next month" : "Seuraava kuukausi",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Pakan käytön rajoittaminen estää merkittyjen ryhmien jäseniä luomasta omia taulujaan, mutta käyttäjät pystyvät silti käyttämään heidän kanssaan jaettuja tauluja."
 },
 "nplurals=2; plural=(n != 1);");
