@@ -63,14 +63,16 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} שיחזר את הקובץ המצורף {attachment} לכרטיס {card}",
     "You have commented on card {card}" : "הגבת על הכרטיס {cart}",
     "{user} has commented on card {card}" : "נוספה תגובה מאת {user} על הכרטיס {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
     "Deck" : "חפיסה",
     "Changes in the <strong>Deck app</strong>" : "שינויים ל<strong>יישומון החבילה</strong>",
+    "A <strong>board, list or card</strong> was changed" : "לוח, רשימה או כרטיס שונה",
     "A <strong>comment</strong> was created on a card" : "נוצרה <strong>הערה</strong> על כרטיס",
+    "A <strong>card description</strong> has been changed" : "תיאור הכרטיס שונה",
     "Upcoming cards" : "כרטיסים עתידיים",
     "Load more" : "לטעון עוד",
     "Personal" : "אישי",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} has assigned the card {deck-card} on {deck-board} to you.",
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
     "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
     "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
@@ -105,11 +107,8 @@ OC.L10N.register(
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
     "Select a board" : "נא לבחור לוח",
-    "Select a list" : "בחר רשימה",
-    "Cancel" : "ביטול",
-    "Close" : "סגירה",
-    "Create card" : "יצירת כרטיס",
     "Select a card" : "נא לבחור כרטיס",
+    "Cancel" : "ביטול",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Link to card" : "קישור לכרטיס",
     "File already exists" : "הקובץ כבר קיים",
@@ -146,7 +145,7 @@ OC.L10N.register(
     "Sharing" : "שיתוף",
     "Tags" : "תגיות",
     "Deleted items" : "פריטים שנמחקו",
-    "Timeline" : "ציר זמן",
+    "Activity" : "פעילות",
     "Deleted lists" : "רשימות שנמחקו",
     "Undo" : "ביטול",
     "Deleted cards" : "כרטיסים שנמחקו",
@@ -174,6 +173,8 @@ OC.L10N.register(
     "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Board name" : "שם הלוח",
     "Members" : "חברים",
+    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
+    "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
     "Upload new files" : "העלאת קבצים חדשים",
     "Share from Files" : "שיתוף מקבצים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
@@ -191,24 +192,13 @@ OC.L10N.register(
     "Created" : "מועד היצירה",
     "The title cannot be empty." : "הכותרת לא יכולה להיות ריקה.",
     "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
-    "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
-    "Assign to users" : "הקצאה למשתמשים",
-    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
-    "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
-    "Due date" : "מועד יעד",
-    "Set a due date" : "הגדרת תאריך יעד",
-    "Remove due date" : "הסרת מועד התפוגה",
-    "Select Date" : "בחירת תאריך",
-    "Today" : "היום",
-    "Tomorrow" : "מחר",
-    "Next week" : "השבוע הבא",
-    "Next month" : "החודש הבא",
     "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
     "In reply to" : "בתגובה אל",
     "Reply" : "תגובה",
     "Update" : "עדכון",
+    "Created:" : "מועד היצירה:",
     "Description" : "תיאור",
     "(Unsaved)" : "(לא נשמר)",
     "(Saving…)" : "(מתבצעת שמירה…)",
@@ -218,15 +208,21 @@ OC.L10N.register(
     "Add Attachment" : "הוספת קובץ מצורף",
     "Write a description …" : "כתוב תיאור ...",
     "Choose attachment" : "בחירת קובץ מצורף",
+    "Set a due date" : "הגדרת תאריך יעד",
+    "Remove due date" : "הסרת מועד התפוגה",
+    "Completed" : "הושלם",
+    "Unarchive card" : "הוצאת הכרטיס מהארכיון",
+    "Archive card" : "העברת כרטיס לארכיון",
+    "Select Date" : "בחירת תאריך",
+    "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
     "(group)" : "(קבוצה)",
+    "Card details" : "פרטי הכרטיס",
     "Assign to me" : "הקצאה אלי",
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Move card" : "העברת כרטיס",
-    "Card details" : "פרטי הכרטיס",
-    "Unarchive card" : "הוצאת הכרטיס מהארכיון",
-    "Archive card" : "העברת כרטיס לארכיון",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "Move card to another board" : "העברת כרטיס ללוח אחר",
+    "Select a list" : "בחר רשימה",
     "List is empty" : "הרשימה ריקה",
     "Card deleted" : "הכרטיס נמחק",
     "seconds ago" : "לפני מספר שניות",
@@ -235,8 +231,6 @@ OC.L10N.register(
     "Shared with you" : "משותף אתך",
     "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
     "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
-    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
     "Board details" : "פרטי לוח",
     "Edit board" : "עריכת לוח",
     "Clone board" : "שכפל את הלוח",
@@ -255,8 +249,12 @@ OC.L10N.register(
     "An error occurred" : "אירעה שגיאה",
     "Delete the board?" : "למחוק את הלוח הזה?",
     "Loading filtered view" : "טוען תצוגה מסוננת",
+    "Today" : "היום",
+    "Tomorrow" : "מחר",
     "No due" : "אין תאריך יעד",
     "No results found" : "לא נמצאו תוצאות",
+    "Create card" : "יצירת כרטיס",
+    "Close" : "סגירה",
     "No upcoming cards" : "אין כרטיסים עתידיים",
     "upcoming cards" : "כרטיסים עתידיים",
     "Link to a board" : "קישור ללוח",
@@ -268,6 +266,14 @@ OC.L10N.register(
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
-    "Add a new list" : "הוסף רשימה חדשה"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
+    "Timeline" : "ציר זמן",
+    "Add a new list" : "הוסף רשימה חדשה",
+    "Assign to users" : "הקצאה למשתמשים",
+    "Due date" : "מועד יעד",
+    "Next week" : "השבוע הבא",
+    "Next month" : "החודש הבא",
+    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
