@@ -63,7 +63,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} je vratio privitak {attachment} na karticu {card}",
     "You have commented on card {card}" : "Komentirali ste karticu {card}",
     "{user} has commented on card {card}" : "{user} je komentirao karticu {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Promijenjen je <strong>opis kartice</strong> u aplikaciji Deck",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Promjene u <strong>aplikaciji Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Na kartici je stvoren <strong>komentar</strong>",
@@ -110,17 +109,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Odaberite ploču za povezivanje s projektom",
     "Search by board title" : "Traži po naslovu ploče",
     "Select board" : "Odaberi ploču",
-    "Create a new card" : "Stvori novu karticu",
     "Select a board" : "Odaberite ploču",
-    "Select a list" : "Odaberi popis",
-    "Card title" : "Naslov kartice",
-    "Cancel" : "Odustani",
-    "Creating the new card …" : "Stvaranje nove kartice…",
-    "Card \"{card}\" was added to \"{board}\"" : "Kartica „{card}” je dodana na „{board}”",
-    "Open card" : "Otvori karticu",
-    "Close" : "Zatvori",
-    "Create card" : "Stvori karticu",
     "Select a card" : "Odaberite karticu",
+    "Cancel" : "Odustani",
     "Select the card to link to a project" : "Odaberite karticu za povezivanje s projektom",
     "Link to card" : "Poveznica na karticu",
     "File already exists" : "Datoteka već postoji",
@@ -157,7 +148,7 @@ OC.L10N.register(
     "Sharing" : "Dijeljenje",
     "Tags" : "Oznake",
     "Deleted items" : "Izbrisane stavke",
-    "Timeline" : "Vremenska crta",
+    "Activity" : "Aktivnost",
     "Deleted lists" : "Izbrisani popisi",
     "Undo" : "Poništi",
     "Deleted cards" : "Izbrisane kartice",
@@ -185,6 +176,8 @@ OC.L10N.register(
     "title and color value must be provided" : "potrebno je odabrati naziv i vrijednost boje",
     "Board name" : "Naziv ploče",
     "Members" : "Članovi",
+    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima",
+    "Assign a user to this card…" : "Dodijeli korisnika ovoj kartici...",
     "Upload new files" : "Otpremi nove datoteke",
     "Share from Files" : "Dijeli iz datoteka",
     "Add this attachment" : "Dodajte ovaj privitak",
@@ -203,18 +196,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Naslov ne može biti prazan.",
     "No comments yet. Begin the discussion!" : "Nema komentara. Započnite raspravu!",
     "Failed to load comments" : "Učitavanje komentara nije uspjelo",
-    "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
-    "Assign to users" : "Dodijeli korisnicima",
-    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima",
-    "Assign a user to this card…" : "Dodijeli korisnika ovoj kartici...",
-    "Due date" : "Datum dospijeća",
-    "Set a due date" : "Postavi datum dospijeća",
-    "Remove due date" : "Ukloni datum dospijeća",
-    "Select Date" : "Odaberi datum",
-    "Today" : "Danas",
-    "Tomorrow" : "Sutra",
-    "Next week" : "Sljedeći tjedan",
-    "Next month" : "Sljedeći mjesec",
     "Save" : "Spremi",
     "The comment cannot be empty." : "Komentar ne može biti prazan.",
     "The comment cannot be longer than 1000 characters." : "Komentar ne može duži od 1000 znakova.",
@@ -222,6 +203,7 @@ OC.L10N.register(
     "Cancel reply" : "Prekini odgovor",
     "Reply" : "Odgovori",
     "Update" : "Ažuriraj",
+    "Created:" : "Stvoreno:",
     "Description" : "Opis",
     "(Unsaved)" : "(Nije spremljeno)",
     "(Saving…)" : "(Spremanje…)",
@@ -231,16 +213,23 @@ OC.L10N.register(
     "Add Attachment" : "Dodaj privitak",
     "Write a description …" : "Napišite opis...",
     "Choose attachment" : "Odaberi privitak",
-    "(group)" : "(grupa)",
-    "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
-    "Assign to me" : "Dodijeli meni",
-    "Unassign myself" : "Ukloni sebe",
-    "Move card" : "Premjesti karticu",
-    "Card details" : "Pojedinosti o kartici",
+    "Set a due date" : "Postavi datum dospijeća",
+    "Remove due date" : "Ukloni datum dospijeća",
+    "Completed" : "Završeno",
     "Unarchive card" : "Dearhiviraj karticu",
     "Archive card" : "Arhiviraj karticu",
+    "Select Date" : "Odaberi datum",
+    "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
+    "(group)" : "(grupa)",
+    "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
+    "Card details" : "Pojedinosti o kartici",
+    "Assign to me" : "Dodijeli meni",
+    "Unassign myself" : "Ukloni sebe",
+    "Mark as done" : "Označi kao završeno",
+    "Move card" : "Premjesti karticu",
     "Delete card" : "Izbriši karticu",
     "Move card to another board" : "Premjesti karticu na drugu ploču",
+    "Select a list" : "Odaberi popis",
     "List is empty" : "Popis je prazan",
     "Card deleted" : "Kartica je izbrisana",
     "seconds ago" : "prije nekoliko sekundi",
@@ -249,8 +238,6 @@ OC.L10N.register(
     "Shared with you" : "Podijeljeno s vama",
     "Use bigger card view" : "Prikaži veće kartice",
     "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
-    "Limit deck usage of groups" : "Ograniči uporabu decka grupama",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ograničenjem Decka možete spriječiti korisnike koji ne sudjeluju u tim grupama da stvaraju vlastite ploče. Korisnici će i dalje moći raditi na pločama koje su dijeljene s njima.",
     "Board details" : "Pojedinosti o ploči",
     "Edit board" : "Uredi ploču",
     "Clone board" : "Kloniraj ploču",
@@ -269,10 +256,19 @@ OC.L10N.register(
     "An error occurred" : "Došlo je do pogreške",
     "Delete the board?" : "Želite li izbrisati ploču?",
     "Loading filtered view" : "Učitavanje filtriranog prikaza",
+    "Today" : "Danas",
+    "Tomorrow" : "Sutra",
     "No due" : "Nema nezavršenih",
     "Search for {searchQuery} in all boards" : "Traži {searchQuery} na svim pločama",
     "No results found" : "Nema rezultata",
     "{stack} in {board}" : "{stack} u {board}",
+    "Create a new card" : "Stvori novu karticu",
+    "Card title" : "Naslov kartice",
+    "Create card" : "Stvori karticu",
+    "Creating the new card …" : "Stvaranje nove kartice…",
+    "Card \"{card}\" was added to \"{board}\"" : "Kartica „{card}” je dodana na „{board}”",
+    "Open card" : "Otvori karticu",
+    "Close" : "Zatvori",
     "No upcoming cards" : "Nema nadolazećih kartica",
     "upcoming cards" : "nadolazeće kartice",
     "Link to a board" : "Poveznica na ploču",
@@ -286,6 +282,14 @@ OC.L10N.register(
     "Share with a Deck card" : "Dijeli s Deck karticom",
     "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
     "Share" : "Dijeli",
-    "Add a new list" : "Dodaj novi popis"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "Promijenjen je <strong>opis kartice</strong> u aplikaciji Deck",
+    "Timeline" : "Vremenska crta",
+    "Add a new list" : "Dodaj novi popis",
+    "Assign to users" : "Dodijeli korisnicima",
+    "Due date" : "Datum dospijeća",
+    "Next week" : "Sljedeći tjedan",
+    "Next month" : "Sljedeći mjesec",
+    "Limit deck usage of groups" : "Ograniči uporabu decka grupama",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ograničenjem Decka možete spriječiti korisnike koji ne sudjeluju u tim grupama da stvaraju vlastite ploče. Korisnici će i dalje moći raditi na pločama koje su dijeljene s njima."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
