@@ -11,10 +11,10 @@ OC.L10N.register(
     "No file was uploaded" : "Nulle file esseva incargate",
     "Missing a temporary folder" : "Il manca un dossier temporari",
     "Cancel" : "Cancellar",
-    "Close" : "Clauder",
     "Details" : "Detalios",
     "Sharing" : "Compartente",
     "Tags" : "Etiquettas",
+    "Activity" : "Activitate",
     "Undo" : "Disfacer",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
@@ -26,16 +26,19 @@ OC.L10N.register(
     "Attachments" : "Attachamentos",
     "Comments" : "Commentarios",
     "Modified" : "Modificate",
-    "Today" : "Hodie",
-    "Tomorrow" : "Deman",
     "Save" : "Salveguardar",
     "Reply" : "Responder",
     "Update" : "Actualisation",
+    "Created:" : "Create:",
     "Description" : "Description",
+    "Completed" : "Completate",
     "(group)" : "(gruppo)",
     "seconds ago" : "secundas passate",
     "Shared with you" : "Compartite con te",
     "No notifications" : "Nulle notificationes",
+    "Today" : "Hodie",
+    "Tomorrow" : "Deman",
+    "Close" : "Clauder",
     "Share" : "Compartir"
 },
 "nplurals=2; plural=(n != 1);");
