@@ -63,7 +63,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} telah memulihkan lampiran {attachment} ke kartu {card}",
     "You have commented on card {card}" : "Anda telah berkomentar pada kartu {card}",
     "{user} has commented on card {card}" : "{user} telah berkomentar pada kartu {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Deskripsi kartu</strong> didalam aplikasi Longgok telah diubah",
     "Deck" : "Longgok",
     "Changes in the <strong>Deck app</strong>" : "Perubahan pada <strong>aplikasi Longgok</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Komentar</strong> telah dibuat pada suatu kartu",
@@ -102,10 +101,8 @@ OC.L10N.register(
     "Search by board title" : "Cari berdasarkan judul papan",
     "Select board" : "Pilih papan",
     "Select a board" : "Pilih papan",
-    "Select a list" : "Pilih daftar",
-    "Cancel" : "Membatalkan",
-    "Close" : "Tutup",
     "Select a card" : "Pilih kartu",
+    "Cancel" : "Membatalkan",
     "Select the card to link to a project" : "Pilih kartu untuk ditautkan ke proyek",
     "Link to card" : "Tautan ke kartu",
     "File already exists" : "Berkas sudah ada",
@@ -138,7 +135,7 @@ OC.L10N.register(
     "Sharing" : "Berbagi",
     "Tags" : "Tag",
     "Deleted items" : "Entri terhapus",
-    "Timeline" : "Linimasa",
+    "Activity" : "Aktivitas",
     "Deleted lists" : "Daftar terhapus",
     "Undo" : "Undo",
     "Deleted cards" : "Kartu terhapus",
@@ -158,6 +155,8 @@ OC.L10N.register(
     "Add a new tag" : "Tambah tag baru",
     "title and color value must be provided" : "judul dan nilai warna harus ditentukan",
     "Members" : "Anggota",
+    "Assign to users/groups/circles" : "Penugasan kepada pengguna/grup/lingkaran",
+    "Assign a user to this card…" : "Menugaskan pengguna kepada kartu ini..",
     "Add this attachment" : "Tambah lampiran ini",
     "Download" : "Unduh",
     "Delete Attachment" : "Hapus Lampiran",
@@ -168,23 +167,13 @@ OC.L10N.register(
     "Modified" : "Dimodifikasi",
     "Created" : "Dibuat",
     "No comments yet. Begin the discussion!" : "Belum ada komentar. Mulai berdiskusi!",
-    "Assign a tag to this card…" : "Berikan tag pada kartu ini...",
-    "Assign to users" : "Penugasan kepada pengguna",
-    "Assign to users/groups/circles" : "Penugasan kepada pengguna/grup/lingkaran",
-    "Assign a user to this card…" : "Menugaskan pengguna kepada kartu ini..",
-    "Due date" : "Tenggat",
-    "Set a due date" : "Tentukan tenggat",
-    "Remove due date" : "Hapus tenggat",
-    "Today" : "Hari ini",
-    "Tomorrow" : "Besok",
-    "Next week" : "Minggu setelah",
-    "Next month" : "Bulan setelah",
     "Save" : "Simpan",
     "The comment cannot be empty." : "Komentar tidak dapat kosong.",
     "The comment cannot be longer than 1000 characters." : "Komentar tidak dapat melebihi 1000 karakter.",
     "In reply to" : "Membalas kepada",
     "Reply" : "Balas",
     "Update" : "Perbarui",
+    "Created:" : "Dibuat:",
     "Description" : "Deskrisi",
     "(Unsaved)" : "(Tidak tersimpan)",
     "(Saving…)" : "(Menyimpan…)",
@@ -193,20 +182,24 @@ OC.L10N.register(
     "View description" : "Tampilkan deskripsi",
     "Add Attachment" : "Tambah Lampiran",
     "Choose attachment" : "Pilih lampiran",
-    "(group)" : "(grup)",
-    "Assign to me" : "Tugaskan saya",
-    "Move card" : "Pindahkan kartu",
-    "Card details" : "Detail kartu",
+    "Set a due date" : "Tentukan tenggat",
+    "Remove due date" : "Hapus tenggat",
+    "Completed" : "Selesai",
     "Unarchive card" : "Memulihkan kartu",
     "Archive card" : "Mengarsipkan kartu",
+    "Assign a tag to this card…" : "Berikan tag pada kartu ini...",
+    "(group)" : "(grup)",
+    "Card details" : "Detail kartu",
+    "Assign to me" : "Tugaskan saya",
+    "Mark as done" : "Tandai sebagai selesai",
+    "Move card" : "Pindahkan kartu",
     "Delete card" : "Hapus kartu",
     "Move card to another board" : "Pindahkan kartu ke papan lain",
+    "Select a list" : "Pilih daftar",
     "seconds ago" : "beberapa detik yang lalu",
     "All boards" : "Semua papan",
     "Archived boards" : "Papan terarsip",
     "Shared with you" : "Shared with you",
-    "Limit deck usage of groups" : "Batasi grup pengguna longgok ",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Membatasi Longgok akan mencegah pengguna bukan bagian dari grup, untuk membuat papan mereka sendiri. Pengguna tetap menggunakan papan yang telah dibagikan kepadanya.",
     "Board details" : "Detail papan",
     "Edit board" : "Edit papan",
     "Clone board" : "Pengklonaan papan",
@@ -217,7 +210,10 @@ OC.L10N.register(
     "Board {0} deleted" : "{0} papan terhapus",
     "An error occurred" : "Terjadi kesalahan",
     "Delete the board?" : "Hapus papan?",
+    "Today" : "Hari ini",
+    "Tomorrow" : "Besok",
     "Click to expand comment" : "Klik untuk membuka komentar",
+    "Close" : "Tutup",
     "No upcoming cards" : "Tidak ada kartu berikut",
     "upcoming cards" : "kartu berikut",
     "Link to a board" : "Tautan ke papan",
@@ -225,6 +221,14 @@ OC.L10N.register(
     "Something went wrong" : "Ada yang salah",
     "Maximum file size of {size} exceeded" : "Melampaui batas ukuran maksimal {size}",
     "Share" : "Bagikan",
-    "Add a new list" : "Tambah daftar baru"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Deskripsi kartu</strong> didalam aplikasi Longgok telah diubah",
+    "Timeline" : "Linimasa",
+    "Add a new list" : "Tambah daftar baru",
+    "Assign to users" : "Penugasan kepada pengguna",
+    "Due date" : "Tenggat",
+    "Next week" : "Minggu setelah",
+    "Next month" : "Bulan setelah",
+    "Limit deck usage of groups" : "Batasi grup pengguna longgok ",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Membatasi Longgok akan mencegah pengguna bukan bagian dari grup, untuk membuat papan mereka sendiri. Pengguna tetap menggunakan papan yang telah dibagikan kepadanya."
 },
 "nplurals=1; plural=0;");
