@@ -39,7 +39,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} endurheimti viðhengið {attachment} á spjaldinu {card}",
     "You have commented on card {card}" : "Þú settir inn athugasemd við spjaldið {card}",
     "{user} has commented on card {card}" : "{user} setti inn athugasemd við spjaldið {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Lýsingu á spjaldi</strong> inni í Deck-spjaldaforritinu hefur verið breytt",
     "Deck" : "Dekk",
     "Changes in the <strong>Deck app</strong>" : "Breytingar í <strong>Deck spjaldaforritinu</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Athugasemd</strong> var gerð á spjaldi",
@@ -77,10 +76,8 @@ OC.L10N.register(
     "Select the board to link to a project" : "Veldu borðið sem á að tengja við verkefnið",
     "Select board" : "Veldu borð",
     "Select a board" : "Veldu borð",
-    "Cancel" : "Hætta við",
-    "Close" : "Loka",
-    "Create card" : "Búa til spjald",
     "Select a card" : "Veldu spjald",
+    "Cancel" : "Hætta við",
     "Select the card to link to a project" : "Veldu spjaldið sem á að tengja við verkefnið",
     "Link to card" : "Tengill á spjald",
     "File already exists" : "Skrá er þegar til",
@@ -108,7 +105,7 @@ OC.L10N.register(
     "Sharing" : "Deiling",
     "Tags" : "Merki",
     "Deleted items" : "Eydd atriði",
-    "Timeline" : "Tímalína",
+    "Activity" : "Virkni",
     "Undo" : "Afturkalla",
     "Deleted cards" : "Eydd spjöld",
     "Share board with a user, group or circle …" : "Deila borði með notanda, hóp eða hring …",
@@ -127,6 +124,7 @@ OC.L10N.register(
     "Edit" : "Breyta",
     "title and color value must be provided" : "titill og litgildi verða að vera til staðar",
     "Members" : "Meðlimir",
+    "Assign a user to this card…" : "Úthluta notanda á þetta spjald",
     "Download" : "Sækja",
     "File to share" : "Skrá til að deila",
     "Invalid path selected" : "Ógild slóð valin",
@@ -135,36 +133,30 @@ OC.L10N.register(
     "Modified" : "Breytt",
     "Created" : "Búið til þann",
     "No comments yet. Begin the discussion!" : "Engar athugasemdir ennþá. Byrjaðu umræðuna!",
-    "Assign a tag to this card…" : "Úthluta merki á þetta spjald",
-    "Assign to users" : "Úthluta á notendur",
-    "Assign a user to this card…" : "Úthluta notanda á þetta spjald",
-    "Due date" : "Skiladagur",
-    "Set a due date" : "Setja lokadag",
-    "Remove due date" : "Fjarlægja skiladag",
-    "Select Date" : "Veldu dag",
-    "Today" : "Í dag",
-    "Tomorrow" : "Á morgun",
-    "Next week" : "Næsta viku",
-    "Next month" : "Næsti mánuður",
     "Save" : "Vista",
     "The comment cannot be empty." : "Athugasemdin má ekki vera tóm.",
     "The comment cannot be longer than 1000 characters." : "Athugasemdin má ekki vera lengri en 1000 stafir.",
     "Reply" : "Svara",
     "Update" : "Uppfæra",
+    "Created:" : "Búið til:",
     "Description" : "Lýsing",
     "Formatting help" : "Hjálp við að sníða",
-    "(group)" : "(hópur)",
-    "Assign to me" : "Úthluta mér",
-    "Move card" : "Færa spjald",
-    "Card details" : "Nánar um spjald",
+    "Set a due date" : "Setja lokadag",
+    "Remove due date" : "Fjarlægja skiladag",
+    "Completed" : "Lokið",
     "Unarchive card" : "Taka spjald úr geymslu",
     "Archive card" : "Setja spjald í geymslu",
+    "Select Date" : "Veldu dag",
+    "Assign a tag to this card…" : "Úthluta merki á þetta spjald",
+    "(group)" : "(hópur)",
+    "Card details" : "Nánar um spjald",
+    "Assign to me" : "Úthluta mér",
+    "Move card" : "Færa spjald",
     "Delete card" : "Eyða spjaldi",
     "seconds ago" : "sekúndum síðan",
     "All boards" : "Öll borð",
     "Archived boards" : "Borð í geymslu",
     "Shared with you" : "Deilt með þér",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Takmörkun í  Deck spjaldaforritinu mun loka notendur sem tilheyra ekki þessum hópum frá því að útbúa sín eigin borð. Notendurnir munu samt geta áfram unnið með borð sem hefur verið deilt til þeirra.",
     "Board details" : "Nánar um borð",
     "Edit board" : "Breyta borði",
     "Clone board" : "Klóna borð",
@@ -174,11 +166,22 @@ OC.L10N.register(
     "Delete board" : "Eyða borði",
     "No reminder" : "Engin áminning",
     "An error occurred" : "Villa kom upp",
+    "Today" : "Í dag",
+    "Tomorrow" : "Á morgun",
     "No results found" : "Engar niðurstöður fundust",
+    "Create card" : "Búa til spjald",
+    "Close" : "Loka",
     "Link to a board" : "Tengill við borð",
     "Link to a card" : "Tengja við spjald",
     "Something went wrong" : "Eitthvað fór úrskeiðis",
     "Maximum file size of {size} exceeded" : "Fór yfir hámarks skráarstærð {size}",
-    "Share" : "Deila"
+    "Share" : "Deila",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Lýsingu á spjaldi</strong> inni í Deck-spjaldaforritinu hefur verið breytt",
+    "Timeline" : "Tímalína",
+    "Assign to users" : "Úthluta á notendur",
+    "Due date" : "Skiladagur",
+    "Next week" : "Næsta viku",
+    "Next month" : "Næsti mánuður",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Takmörkun í  Deck spjaldaforritinu mun loka notendur sem tilheyra ekki þessum hópum frá því að útbúa sín eigin borð. Notendurnir munu samt geta áfram unnið með borð sem hefur verið deilt til þeirra."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
