@@ -63,7 +63,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に復元しました",
     "You have commented on card {card}" : "カード{card}にコメントしました",
     "{user} has commented on card {card}" : "{user}がカード{card}にコメントしました",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
     "Deck" : "デッキ",
     "Changes in the <strong>Deck app</strong>" : "<strong>デッキアプリ</strong>に変更があったとき",
     "A <strong>comment</strong> was created on a card" : "カードに<strong>コメント</strong>が作成されたとき",
@@ -112,17 +111,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
-    "Create a new card" : "新しいカードを作成する",
     "Select a board" : "ボードを選択",
-    "Select a list" : "リストを選択",
-    "Card title" : "カードのタイトル",
-    "Cancel" : "キャンセル",
-    "Creating the new card …" : "新しいカードを作成しています...",
-    "Card \"{card}\" was added to \"{board}\"" : "カード \"{card}\" が \"{board}\" に追加されました",
-    "Open card" : "カードを開く",
-    "Close" : "閉じる",
-    "Create card" : "カードを作成",
     "Select a card" : "カードを選択",
+    "Cancel" : "キャンセル",
     "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
     "Link to card" : "カードへリンク",
     "File already exists" : "ファイルはすでに存在します",
@@ -160,7 +151,7 @@ OC.L10N.register(
     "Sharing" : "共有中",
     "Tags" : "タグ",
     "Deleted items" : "削除されたアイテム",
-    "Timeline" : "タイムライン",
+    "Activity" : "アクティビティ",
     "Deleted lists" : "削除済みリスト",
     "Undo" : "元に戻す",
     "Deleted cards" : "削除済みのカード",
@@ -192,6 +183,8 @@ OC.L10N.register(
     "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
     "Board name" : "ボード名",
     "Members" : "メンバー",
+    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
+    "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
     "Upload new files" : "新しいファイルをアップロード",
     "Share from Files" : "ファイルから共有",
     "Pending share" : "共有を保留中",
@@ -212,18 +205,6 @@ OC.L10N.register(
     "The title cannot be empty." : "タイトルを空にすることはできません。",
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "Failed to load comments" : "コメントの読み込みに失敗しました",
-    "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
-    "Assign to users" : "ユーザーに割り当てる",
-    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
-    "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
-    "Due date" : "期限",
-    "Set a due date" : "期限を設定",
-    "Remove due date" : "期限を削除",
-    "Select Date" : "日付を選択",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
-    "Next week" : "来週",
-    "Next month" : "来月",
     "Save" : "保存",
     "The comment cannot be empty." : "コメントを空にすることはできません。",
     "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
@@ -231,6 +212,7 @@ OC.L10N.register(
     "Cancel reply" : "返信をキャンセル",
     "Reply" : "返信",
     "Update" : "更新",
+    "Created:" : "作成:",
     "Description" : "説明",
     "(Unsaved)" : "(未保存)",
     "(Saving…)" : "(保存中…)",
@@ -240,16 +222,23 @@ OC.L10N.register(
     "Add Attachment" : "添付ファイルを追加",
     "Write a description …" : "説明を書く…",
     "Choose attachment" : "添付ファイルを選択",
-    "(group)" : "(グループ)",
-    "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
-    "Assign to me" : "自分に割り当てる",
-    "Unassign myself" : "自分への割り当てを解除",
-    "Move card" : "カードの移動",
-    "Card details" : "カード詳細",
+    "Set a due date" : "期限を設定",
+    "Remove due date" : "期限を削除",
+    "Completed" : "完了",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
+    "Select Date" : "日付を選択",
+    "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
+    "(group)" : "(グループ)",
+    "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
+    "Card details" : "カード詳細",
+    "Assign to me" : "自分に割り当てる",
+    "Unassign myself" : "自分への割り当てを解除",
+    "Mark as done" : "完了としてマーク",
+    "Move card" : "カードの移動",
     "Delete card" : "カードを削除する",
     "Move card to another board" : "カードを他のボードに移動",
+    "Select a list" : "リストを選択",
     "List is empty" : "リストが空です",
     "Card deleted" : "カードが削除されました",
     "seconds ago" : "数秒前",
@@ -258,8 +247,6 @@ OC.L10N.register(
     "Shared with you" : "あなたと共有済み",
     "Use bigger card view" : "大きなカードビューを使用する",
     "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
-    "Limit deck usage of groups" : "デッキの使用をグループに制限",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
     "Board details" : "ボードの詳細",
     "Edit board" : "ボードを編集",
     "Clone board" : "ボードを複製",
@@ -278,10 +265,19 @@ OC.L10N.register(
     "An error occurred" : "エラーが発生しました",
     "Delete the board?" : "ボードを削除しますか？",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
     "No due" : "日付なし",
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
     "No results found" : "結果が見つかりません",
     "{stack} in {board}" : "{board} 内の {stack}",
+    "Create a new card" : "新しいカードを作成する",
+    "Card title" : "カードのタイトル",
+    "Create card" : "カードを作成",
+    "Creating the new card …" : "新しいカードを作成しています...",
+    "Card \"{card}\" was added to \"{board}\"" : "カード \"{card}\" が \"{board}\" に追加されました",
+    "Open card" : "カードを開く",
+    "Close" : "閉じる",
     "No upcoming cards" : "今後のカードはありません",
     "upcoming cards" : "今後のカード",
     "Link to a board" : "ボードへのリンク",
@@ -295,6 +291,14 @@ OC.L10N.register(
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
     "Share" : "共有",
-    "Add a new list" : "新しいリストを追加"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
+    "Timeline" : "タイムライン",
+    "Add a new list" : "新しいリストを追加",
+    "Assign to users" : "ユーザーに割り当てる",
+    "Due date" : "期限",
+    "Next week" : "来週",
+    "Next month" : "来月",
+    "Limit deck usage of groups" : "デッキの使用をグループに制限",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。"
 },
 "nplurals=1; plural=0;");
