@@ -9,10 +9,10 @@ OC.L10N.register(
     "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
     "Missing a temporary folder" : "Ixuṣ ukaram akudan",
     "Cancel" : "Sefsex",
-    "Close" : "Mdel",
     "Details" : "Talqayt",
     "Sharing" : "Beṭṭu",
     "Tags" : "Tibzimin",
+    "Activity" : "Armud",
     "Owner" : "Bab",
     "Delete" : "Kkes",
     "Edit" : "Ẓreg",
@@ -21,11 +21,13 @@ OC.L10N.register(
     "Comments" : "Commentaires",
     "Modified" : "Yettwabeddel",
     "Created" : "Yettwarna.",
-    "Today" : "Ass-a",
     "Save" : "Sekles",
     "Cancel reply" : "Semmet tiririt.",
     "Reply" : "Err",
+    "Completed" : "Yemmed",
     "No notifications" : "Ulac tisezmal",
+    "Today" : "Ass-a",
+    "Close" : "Mdel",
     "Share" : "Bḍu"
 },
 "nplurals=2; plural=(n != 1);");
