@@ -10,6 +10,7 @@ OC.L10N.register(
     "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
     "Deck board" : "Deck 보드",
     "%s on %s" : "%s(%s의)",
+    "No data was provided to create an attachment." : "첨부할 데이터가 제공되지 않았습니다.",
     "Finished" : "완료됨",
     "To review" : "리뷰할 항목",
     "Action needed" : "동작 필요",
@@ -28,16 +29,15 @@ OC.L10N.register(
     "Missing a temporary folder" : "임시 폴더 없음",
     "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
     "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
+    "No file uploaded or file size exceeds maximum of %s" : "파일이 업로드 되지 않았거나 크기가 %s(을)를 초과함",
     "Card not found" : "카드 없음",
-    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다",
+    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다.",
     "Add board" : "보드 추가",
     "Search by board title" : "보드 제목으로 검색",
     "Select board" : "보드 선택",
     "Select a board" : "보드 선택",
-    "Cancel" : "취소",
-    "Close" : "닫기",
-    "Create card" : "크레딧 카드",
     "Select a card" : "카드 선택",
+    "Cancel" : "취소",
     "Select the card to link to a project" : "카드를 선택해 프로젝트에 연결",
     "File already exists" : "파일이 이미 존재함",
     "A file with the name {filename} already exists." : "이미 존재하는  파일이름 {filename} ",
@@ -62,14 +62,15 @@ OC.L10N.register(
     "No due date" : "기한 없음",
     "Hide archived cards" : "보관된 카드 숨기기",
     "Show archived cards" : "보관된 카드 보기",
+    "Toggle compact mode" : "컴팩트 모드 전환",
     "Open details" : "자세한 정보 열기",
     "Details" : "세부사항",
     "Sharing" : "공유",
     "Tags" : "태그",
     "Deleted items" : "삭제된 항목",
-    "Timeline" : "타임라인",
+    "Activity" : "활동",
     "Undo" : "실행 취소",
-    "No participants found" : "참여자를 찾을 수 없음",
+    "No participants found" : "참가자를 찾을 수 없음",
     "(Group)" : "(그룹)",
     "Can edit" : "편집할 수 있음",
     "Can share" : "공유할 수 있음",
@@ -80,7 +81,7 @@ OC.L10N.register(
     "Edit" : "편집",
     "Members" : "구성원",
     "Upload new files" : "새로운 파일 업로드",
-    "Share from Files" : "파일 공유",
+    "Share from Files" : "파일에서 공유",
     "Download" : "다운로드",
     "File to share" : "공유할 파일",
     "Invalid path selected" : "잘못된 경로가 선택됨",
@@ -88,24 +89,23 @@ OC.L10N.register(
     "Comments" : "댓글",
     "Modified" : "수정한 날짜",
     "Created" : "생성됨",
-    "Due date" : "만료 날짜",
-    "Remove due date" : "만료 날짜 삭제",
-    "Select Date" : "날짜 선택",
-    "Today" : "오늘",
-    "Tomorrow" : "내일",
-    "Next week" : "다음주",
-    "Next month" : "다음달",
     "Save" : "저장",
     "Cancel reply" : "응답 취소",
     "Reply" : "답장",
     "Update" : "업데이트",
+    "Created:" : "생성한 날짜:",
     "Description" : "설명",
     "Formatting help" : "서식 도움말",
     "Edit description" : "설명 편집",
-    "(group)" : "(그룹)",
-    "Move card" : "카드 이동",
-    "Card details" : "카드 세부사항",
+    "Remove due date" : "만료 날짜 삭제",
+    "Completed" : "완료됨",
+    "Not completed" : "완성되지 않았다",
     "Archive card" : "보관 카드",
+    "Select Date" : "날짜 선택",
+    "(group)" : "(그룹)",
+    "Next week – {timeLocale}" : "다음주 – {timeLocale}",
+    "Card details" : "카드 세부사항",
+    "Move card" : "카드 이동",
     "Delete card" : "카드 삭제",
     "List is empty" : "목록이 비어 있음",
     "seconds ago" : "초 전",
@@ -122,8 +122,21 @@ OC.L10N.register(
     "No reminder" : "알림 없음",
     "An error occurred" : "오류가 발생함",
     "Delete the board?" : "보드를 삭제합니까?",
+    "Today" : "오늘",
+    "Tomorrow" : "내일",
     "No results found" : "결과 없음",
+    "This weekend – {timeLocale}" : "이번 주말 – {timeLocale}",
+    "{stack} in {board}" : "{board}의 {stack}",
+    "Create card" : "크레딧 카드",
+    "Close" : "닫기",
+    "Tomorrow – {timeLocale}" : "내일 – {timeLocale}",
+    "Later today – {timeLocale}" : "오늘 나중 – {timeLocale}",
     "Something went wrong" : "잘못된 접근",
-    "Share" : "공유"
+    "Error creating the share" : "공유를 만드는 중 오류 발생",
+    "Share" : "공유",
+    "Timeline" : "타임라인",
+    "Due date" : "만료 날짜",
+    "Next week" : "다음주",
+    "Next month" : "다음달"
 },
 "nplurals=1; plural=0;");
