@@ -4,11 +4,13 @@ OC.L10N.register(
     "Personal" : "ສ່ວນບຸກຄົນ",
     "Finished" : "ສຳເລັດ",
     "Done" : "ສໍາເລັດ",
+    "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
+    "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
     "Cancel" : "ຍົກເລີກ",
-    "Close" : "ປິດ",
     "Details" : "ລາຍລະອຽດ",
     "Sharing" : "ການແບ່ງປັນ",
     "Tags" : "ປ້າຍກຳກັບ",
+    "Activity" : "ກິດຈະກໍາ",
     "Can edit" : "ແກ້ໄຂໄດ້",
     "Can share" : "ແບ່ງປັນໄດ້",
     "Owner" : "ເຈົ້າຂອງ",
@@ -17,11 +19,13 @@ OC.L10N.register(
     "Download" : "ດາວໂຫລດ",
     "Comments" : "ຄໍາເຫັນ",
     "Modified" : "\"{name}\" ແມ່ນຊື່ໄຟລ໌ທີ່ບໍ່ຖືກຕ້ອງ.",
-    "Today" : "ມື້ນີ້",
     "Save" : "ບັນທຶກ",
+    "Completed" : "ສຳເລັດ",
     "seconds ago" : "ວິນາທີຜ່ານມາ",
     "Shared with you" : "ແບ່ງປັບກັບທ່ານ",
     "No notifications" : "ບໍ່ມີການແຈ້ງເຕືອນ",
+    "Today" : "ມື້ນີ້",
+    "Close" : "ປິດ",
     "Share" : "ແບ່ງປັນ"
 },
 "nplurals=1; plural=0;");
