@@ -61,7 +61,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} atkūrė priedą {attachment} į kortelę {card}",
     "You have commented on card {card}" : "Jūs pakomentavote kortelėje {card}",
     "{user} has commented on card {card}" : "{user} pakomentavo kortelėje {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Darbų programėlėje pakeistas <strong>kortelės aprašas</strong> ",
     "Deck" : "Darbai",
     "Changes in the <strong>Deck app</strong>" : "Pakeitimai <strong>Darbų programėlėje</strong>",
     "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
@@ -103,17 +102,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
-    "Create a new card" : "Sukurti naują kortelę",
     "Select a board" : "Pasirinkite lentą",
-    "Select a list" : "Pasirinkite sąrašą",
-    "Card title" : "Kortelės pavadinimas",
-    "Cancel" : "Atsisakyti",
-    "Creating the new card …" : "Kuriama nauja kortelė…",
-    "Card \"{card}\" was added to \"{board}\"" : "Kortelė „{card}“ buvo pridėta į lentą „{board}“",
-    "Open card" : "Atverti kortelę",
-    "Close" : "Užverti",
-    "Create card" : "Sukurti kortelę",
     "Select a card" : "Pasirinkti kortelę",
+    "Cancel" : "Atsisakyti",
     "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Link to card" : "Susieti su kortele",
     "File already exists" : "Failas jau yra",
@@ -148,7 +139,7 @@ OC.L10N.register(
     "Sharing" : "Bendrinimas",
     "Tags" : "Žymės",
     "Deleted items" : "Ištrinti elementai",
-    "Timeline" : "Laiko juosta",
+    "Activity" : "Veikla",
     "Deleted lists" : "Ištrinti sąrašai",
     "Undo" : "Atšaukti",
     "Deleted cards" : "Ištrintos kortelės",
@@ -176,6 +167,8 @@ OC.L10N.register(
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
     "Board name" : "Lentos pavadinimas",
     "Members" : "Nariai",
+    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
+    "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
     "Upload new files" : "Išsiųsti naujus failus",
     "Share from Files" : "Bendrinti iš failų",
     "Add this attachment" : "Pridėti šį priedą",
@@ -195,23 +188,12 @@ OC.L10N.register(
     "The title cannot be empty." : "Pavadinimas negali būti tuščias.",
     "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
     "Failed to load comments" : "Nepavyko įkelti komentarų",
-    "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
-    "Assign to users" : "Priskirti naudotojams",
-    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
-    "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
-    "Due date" : "Galutinio termino data",
-    "Set a due date" : "Nustatyti galutinį terminą",
-    "Remove due date" : "Šalinti galutinio termino datą",
-    "Select Date" : "Pasirinkti datą",
-    "Today" : "Šiandien",
-    "Tomorrow" : "Rytoj",
-    "Next week" : "Kita savaitė",
-    "Next month" : "Kitas mėnuo",
     "Save" : "Įrašyti",
     "The comment cannot be empty." : "Komentaras negali būti tuščias.",
     "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
     "Reply" : "Atsakyti",
     "Update" : "Atnaujinti",
+    "Created:" : "Sukurta:",
     "Description" : "Aprašas",
     "(Unsaved)" : "(Neįrašyta)",
     "(Saving…)" : "(Įrašoma…)",
@@ -221,15 +203,23 @@ OC.L10N.register(
     "Add Attachment" : "Pridėti priedą",
     "Write a description …" : "Parašykite aprašą…",
     "Choose attachment" : "Pasirinkite priedą",
-    "(group)" : "(grupė)",
-    "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
-    "Assign to me" : "Priskirti sau",
-    "Move card" : "Perkelti kortelę",
-    "Card details" : "Išsamiau apie kortelę",
+    "Set a due date" : "Nustatyti galutinį terminą",
+    "Remove due date" : "Šalinti galutinio termino datą",
+    "Completed" : "Užbaigta",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
+    "Select Date" : "Pasirinkti datą",
+    "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
+    "(group)" : "(grupė)",
+    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
+    "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
+    "Card details" : "Išsamiau apie kortelę",
+    "Assign to me" : "Priskirti sau",
+    "Mark as done" : "Žymėti kaip atliktą",
+    "Move card" : "Perkelti kortelę",
     "Delete card" : "Ištrinti kortelę",
     "Move card to another board" : "Perkelti kortelę į kitą lentą",
+    "Select a list" : "Pasirinkite sąrašą",
     "List is empty" : "Sąrašas tuščias",
     "Card deleted" : "Kortelė ištrinta",
     "seconds ago" : "prieš keletą sekundžių",
@@ -255,9 +245,20 @@ OC.L10N.register(
     "No reminder" : "Jokio priminimo",
     "An error occurred" : "Įvyko klaida",
     "Delete the board?" : "Ištrinti lentą?",
+    "Today" : "Šiandien",
+    "Tomorrow" : "Rytoj",
     "No due" : "Be galutinio termino",
     "No results found" : "Nerasta jokių rezultatų",
+    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
+    "Create a new card" : "Sukurti naują kortelę",
+    "Card title" : "Kortelės pavadinimas",
+    "Create card" : "Sukurti kortelę",
+    "Creating the new card …" : "Kuriama nauja kortelė…",
+    "Card \"{card}\" was added to \"{board}\"" : "Kortelė „{card}“ buvo pridėta į lentą „{board}“",
+    "Open card" : "Atverti kortelę",
+    "Close" : "Užverti",
     "Due on {date}" : "Galutinis terminas {date}",
+    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Create a card" : "Sukurti kortelę",
@@ -265,6 +266,12 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
     "Error creating the share" : "Klaida kuriant viešinį",
     "Share" : "Bendrinti",
-    "Add a new list" : "Pridėti naują sąrašą"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "Darbų programėlėje pakeistas <strong>kortelės aprašas</strong> ",
+    "Timeline" : "Laiko juosta",
+    "Add a new list" : "Pridėti naują sąrašą",
+    "Assign to users" : "Priskirti naudotojams",
+    "Due date" : "Galutinio termino data",
+    "Next week" : "Kita savaitė",
+    "Next month" : "Kitas mėnuo"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
