@@ -11,7 +11,6 @@ OC.L10N.register(
     "Missing a temporary folder" : "Trūkst pagaidu mapes",
     "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
     "Cancel" : "Atcelt",
-    "Close" : "Aizvērt",
     "File already exists" : "Datne jau pastāv",
     "Do you want to overwrite it?" : "Vai tu gribi pārrakstīt to?",
     "Hide archived cards" : "Slēpt arhivētās kartes",
@@ -20,6 +19,7 @@ OC.L10N.register(
     "Details" : "Detaļas",
     "Sharing" : "Koplietošana",
     "Tags" : "Birkas",
+    "Activity" : "Darbības",
     "Undo" : "Atsaukt",
     "(Group)" : "(Grupa)",
     "Can edit" : "Var rediģēt",
@@ -34,19 +34,22 @@ OC.L10N.register(
     "Comments" : "Komentāri",
     "Modified" : "Mainīts",
     "Created" : "Izveidots",
-    "Due date" : "Izpildes datums",
-    "Select Date" : "Izvēlieties datumu",
-    "Today" : "Šodien",
-    "Tomorrow" : "Rīt",
     "Save" : "Saglabāt",
     "Reply" : "Atbildēt",
     "Update" : "Atjaunināt",
+    "Created:" : "Izveidots:",
     "Description" : "Apraksts",
+    "Completed" : "Pabeigts",
+    "Select Date" : "Izvēlieties datumu",
     "(group)" : "(grupa)",
     "seconds ago" : "sekundēm",
     "Shared with you" : "Koplietots ar tevi",
     "No notifications" : "Nav paziņojumu",
     "An error occurred" : "Gadījās kļūda",
-    "Share" : "Koplietot"
+    "Today" : "Šodien",
+    "Tomorrow" : "Rīt",
+    "Close" : "Aizvērt",
+    "Share" : "Koplietot",
+    "Due date" : "Izpildes datums"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
