@@ -63,7 +63,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} го врати прилогот {attachment} на картицата {card}",
     "You have commented on card {card}" : "Коментиравте на картицата {card}",
     "{user} has commented on card {card}" : "{user} коментирање на картицата {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Описот на картицата</strong> во апликацијата Deck е изменет",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Промени во <strong>апликацијата Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Коментар</strong> е креиран на картица",
@@ -103,15 +102,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Избери табла за поврзување со проект",
     "Search by board title" : "Барај по име на табла",
     "Select board" : "Избери табла",
-    "Create a new card" : "Креирајте нова картица",
     "Select a board" : "Избери табла",
-    "Select a list" : "Избери листа",
-    "Card title" : "Наслов на картицата",
-    "Cancel" : "Откажи",
-    "Open card" : "Отвори картица",
-    "Close" : "Затвори",
-    "Create card" : "Креирајте картица",
     "Select a card" : "Избери картица",
+    "Cancel" : "Откажи",
     "Select the card to link to a project" : "Избери картица за поврзување со проект",
     "Link to card" : "Линк до картица",
     "File already exists" : "Датотека веќе постои",
@@ -139,6 +132,7 @@ OC.L10N.register(
     "Hide archived cards" : "Сокриј ги архивираните картици",
     "Show archived cards" : "Прикажи ги архивираните картици",
     "Toggle compact mode" : "Вклучи компактен мод",
+    "Open details" : "Отвори детали",
     "Details" : "Детали",
     "Loading board" : "Вчирување на табла",
     "No lists available" : "Нема достапни листи",
@@ -147,7 +141,7 @@ OC.L10N.register(
     "Sharing" : "Споделување",
     "Tags" : "Ознаки",
     "Deleted items" : "Избришани работи",
-    "Timeline" : "Времеплов",
+    "Activity" : "Активност",
     "Deleted lists" : "Избришани листи",
     "Undo" : "Врати",
     "Deleted cards" : "Избришани картици",
@@ -175,6 +169,8 @@ OC.L10N.register(
     "title and color value must be provided" : "наслов и боја мора да се приложи",
     "Board name" : "Име на табла",
     "Members" : "Членови",
+    "Assign to users/groups/circles" : "Додели на корисници/групи/кругови",
+    "Assign a user to this card…" : "Додели корисник на оваа картица...",
     "Upload new files" : "Прикачи нови датотеки",
     "Share from Files" : "Сподели од датотеките",
     "Add this attachment" : "Додади го овој прилог",
@@ -192,24 +188,13 @@ OC.L10N.register(
     "Created" : "Креирано",
     "The title cannot be empty." : "Насловот неможе да биде празен.",
     "No comments yet. Begin the discussion!" : "Сеуште нема коментари. Започни дискусија!",
-    "Assign a tag to this card…" : "Додади ознака на оваа картица...",
-    "Assign to users" : "Додели на корисници",
-    "Assign to users/groups/circles" : "Додели на корисници/групи/кругови",
-    "Assign a user to this card…" : "Додели корисник на оваа картица...",
-    "Due date" : "До датум",
-    "Set a due date" : "Постави краен рок",
-    "Remove due date" : "Отстрани краен рок",
-    "Select Date" : "Избери датум",
-    "Today" : "Денес",
-    "Tomorrow" : "Утре",
-    "Next week" : "Следна недела",
-    "Next month" : "Следен месец",
     "Save" : "Зачувај",
     "The comment cannot be empty." : "Коментарот неможе да биде празен.",
     "The comment cannot be longer than 1000 characters." : "Коментарот неможе да биде поголем од 1000 карактери.",
     "In reply to" : "Како одговор на",
     "Reply" : "Одговор",
     "Update" : "Ажурирај",
+    "Created:" : "Создадено:",
     "Description" : "Опис",
     "(Unsaved)" : "(Незачувано)",
     "(Saving…)" : "(Снимање…)",
@@ -219,15 +204,22 @@ OC.L10N.register(
     "Add Attachment" : "Додади прилог",
     "Write a description …" : "Напиши опис ...",
     "Choose attachment" : "Избери прилог",
-    "(group)" : "(group)",
-    "Assign to me" : "Доделени мене",
-    "Unassign myself" : "Откажи се",
-    "Move card" : "Премести картица",
-    "Card details" : "Детали за картица",
+    "Set a due date" : "Постави краен рок",
+    "Remove due date" : "Отстрани краен рок",
+    "Completed" : "Завршено",
     "Unarchive card" : "Врати картица од архива",
     "Archive card" : "Архивирај картица",
+    "Select Date" : "Избери датум",
+    "Assign a tag to this card…" : "Додади ознака на оваа картица...",
+    "(group)" : "(group)",
+    "Card details" : "Детали за картица",
+    "Assign to me" : "Доделени мене",
+    "Unassign myself" : "Откажи се",
+    "Mark as done" : "Означи како готово",
+    "Move card" : "Премести картица",
     "Delete card" : "Избриши картица",
     "Move card to another board" : "Премести ја картицата на друга табла",
+    "Select a list" : "Избери листа",
     "List is empty" : "Листата е празна",
     "Card deleted" : "Картицата е избришана",
     "seconds ago" : "пред неколку секунди",
@@ -236,8 +228,6 @@ OC.L10N.register(
     "Shared with you" : "Споделено со тебе",
     "Use bigger card view" : "Користи поголем преглед на картици",
     "Show boards in calendar/tasks" : "Прикажи ги таблите во календарнот",
-    "Limit deck usage of groups" : "Ограничи ја апликацијата на групи",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ограничувањето на апликацијата ќе ги блокира корисниците кој не се дел од овие групи. Корсниците ќе можат да работат на апликацијата само доколку биде споделена табла со нив.",
     "Board details" : "Детали за таблата",
     "Edit board" : "Измени табла",
     "Clone board" : "Клонирај табла",
@@ -256,10 +246,20 @@ OC.L10N.register(
     "An error occurred" : "Настана грешка",
     "Delete the board?" : "Бришење на таблата?",
     "Loading filtered view" : "Вчитување на филтриран поглед",
+    "Today" : "Денес",
+    "Tomorrow" : "Утре",
     "No due" : "Не истекува",
     "No results found" : "Нема пронајдено резултати",
+    "{stack} in {board}" : "{stack} во {board}",
+    "Create a new card" : "Креирајте нова картица",
+    "Card title" : "Наслов на картицата",
+    "Create card" : "Креирајте картица",
+    "Open card" : "Отвори картица",
+    "Close" : "Затвори",
     "No upcoming cards" : "Нема престојни картици",
     "upcoming cards" : "престојни картици",
+    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
+    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
     "Link to a board" : "Линк до табла",
     "Link to a card" : "Линк до картица",
     "Create a card" : "Креирајте картица",
@@ -271,6 +271,14 @@ OC.L10N.register(
     "Share with a Deck card" : "Споделено со Deck картица",
     "Share {file} with a Deck card" : "Сподели {file} со Deck картица",
     "Share" : "Сподели",
-    "Add a new list" : "Додади нова листа"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Описот на картицата</strong> во апликацијата Deck е изменет",
+    "Timeline" : "Времеплов",
+    "Add a new list" : "Додади нова листа",
+    "Assign to users" : "Додели на корисници",
+    "Due date" : "До датум",
+    "Next week" : "Следна недела",
+    "Next month" : "Следен месец",
+    "Limit deck usage of groups" : "Ограничи ја апликацијата на групи",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ограничувањето на апликацијата ќе ги блокира корисниците кој не се дел од овие групи. Корсниците ќе можат да работат на апликацијата само доколку биде споделена табла со нив."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
