@@ -13,16 +13,14 @@ OC.L10N.register(
     "Could not write file to disk" : "Escritura impossibla al disc",
     "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
     "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
-    "Create a new card" : "Crear una carta novèla",
     "Cancel" : "Anullar",
-    "Close" : "Tampar",
-    "Create card" : "Crear una carta",
     "File already exists" : "Lo fichièr existís ja",
     "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
     "Details" : "Detalhs",
     "Sharing" : "Partiment",
     "Tags" : "Etiquetas",
     "Deleted items" : "Elements suprimits",
+    "Activity" : "Activitat",
     "Deleted lists" : "Listas suprimidas",
     "Undo" : "Desfar",
     "(Group)" : "(Grop)",
@@ -39,21 +37,26 @@ OC.L10N.register(
     "Invalid path selected" : "Camin seleccionat invalid",
     "Comments" : "Comentaris",
     "Modified" : "Modificat",
-    "Today" : "Uèi",
-    "Tomorrow" : "Deman",
-    "Next week" : "Setmana seguenta",
-    "Next month" : "Mes seguent",
     "Save" : "Salvar",
     "Cancel reply" : "Anullar la responsa",
     "Reply" : "Respondre",
     "Update" : "Metre a jorn",
+    "Created:" : "Creat lo :",
     "Description" : "Descripcion",
+    "Completed" : "Acabat",
     "seconds ago" : "fa qualques segondas",
     "Shared with you" : "Shared with you",
     "No notifications" : "Cap de notificacion",
     "An error occurred" : "Una error s’es producha",
+    "Today" : "Uèi",
+    "Tomorrow" : "Deman",
     "{stack} in {board}" : "{stack} dins {board}",
+    "Create a new card" : "Crear una carta novèla",
+    "Create card" : "Crear una carta",
+    "Close" : "Tampar",
     "Create a card" : "Crear una carta",
-    "Share" : "Partejar"
+    "Share" : "Partejar",
+    "Next week" : "Setmana seguenta",
+    "Next month" : "Mes seguent"
 },
 "nplurals=2; plural=(n > 1);");
