@@ -21,8 +21,8 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
     "Add board" : "Adaugă panou",
     "Cancel" : "Anulează",
-    "Close" : "Închide",
     "File already exists" : "Fișierul există deja",
+    "Add card" : "Adaugă card",
     "Archived cards" : "Carduri arhivate",
     "Add list" : "Adaugă listă ",
     "Filter by tag" : "Filtrare după etichetă",
@@ -36,6 +36,7 @@ OC.L10N.register(
     "Details" : "Detalii",
     "Sharing" : "Partajare",
     "Tags" : "Etichete",
+    "Activity" : "Activitate",
     "Undo" : "Anulează ultima acțiune",
     "Can edit" : "Poate edita",
     "Can share" : "Can share",
@@ -49,19 +50,16 @@ OC.L10N.register(
     "Attachments" : "Atașamente ",
     "Comments" : "Comentarii",
     "Modified" : "Modificat",
-    "Due date" : "Data scadenței",
-    "Today" : "Azi",
-    "Tomorrow" : "Mâine",
-    "Next week" : "Saptămâna următoare",
-    "Next month" : "Luna următoare",
     "Save" : "Salvează",
     "Reply" : "Răspunde",
     "Update" : "Actualizare",
+    "Created:" : "Creat:",
     "Description" : "Descriere",
     "Edit description" : "Editează descriere",
+    "Completed" : "Terminat",
+    "Archive card" : "Arhivează card",
     "(group)" : "(grup)",
     "Move card" : "Mută card",
-    "Archive card" : "Arhivează card",
     "Delete card" : "Șterge card",
     "seconds ago" : "secunde în urmă",
     "Archived boards" : "Panouri arhivate",
@@ -72,6 +70,12 @@ OC.L10N.register(
     "No notifications" : "Nu sunt notificări",
     "Delete board" : "Șterge panou",
     "No reminder" : "Fără mementouri",
-    "Share" : "Partajează"
+    "Today" : "Azi",
+    "Tomorrow" : "Mâine",
+    "Close" : "Închide",
+    "Share" : "Partajează",
+    "Due date" : "Data scadenței",
+    "Next week" : "Saptămâna următoare",
+    "Next month" : "Luna următoare"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
