@@ -63,7 +63,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} at ripristinadu s'alligongiadu {attachment} in s'ischeda {card}",
     "You have commented on card {card}" : "As cummentadu in s'ischeda {card}",
     "{user} has commented on card {card}" : "{user} at cummentadu in s'ischeda {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Sa <strong>descritzione de un'ischeda</strong> in intro de s'aplicatzione Deck app est istada cambiada",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Càmbios in <strong> s'aplicatzione Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Unu <strong>cummentu</strong> est istadu creadu in s'ischeda",
@@ -110,17 +109,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Seletziona lavagna de collegare a unu progetu",
     "Search by board title" : "Chirca dae su tìtulu de sa lavagna",
     "Select board" : "Seletziona lavagna",
-    "Create a new card" : "Crea un'ischeda noa",
     "Select a board" : "Seletziona una lavagna",
-    "Select a list" : "Seletziona un'elencu",
-    "Card title" : "Tìtulu ischeda",
-    "Cancel" : "Annulla",
-    "Creating the new card …" : "Creende s'ischeda noa ...",
-    "Card \"{card}\" was added to \"{board}\"" : "S'ischeda \"{card}\" est istada agiunta a \"{board}\"",
-    "Open card" : "Aberi ischeda",
-    "Close" : "Serra",
-    "Create card" : "Crea ischeda",
     "Select a card" : "Seletziona un'ischeda",
+    "Cancel" : "Annulla",
     "Select the card to link to a project" : "Seletzioan s'ischeda de collegare a unu progetu",
     "Link to card" : "Collega a un'ischeda",
     "File already exists" : "Cust'archìviu ddoe est giai",
@@ -156,7 +147,7 @@ OC.L10N.register(
     "Sharing" : "Cumpartzidura",
     "Tags" : "Etichetas",
     "Deleted items" : "Temas cantzellados",
-    "Timeline" : "Fusu oràriu",
+    "Activity" : "Atividade",
     "Deleted lists" : "Elencos cantzellados",
     "Undo" : "Annulla",
     "Deleted cards" : "Ischeda cantzellada",
@@ -184,6 +175,8 @@ OC.L10N.register(
     "title and color value must be provided" : "tocat de frunire su tìtulu e su balore de su colore",
     "Board name" : "Nùmene de sa lavagna",
     "Members" : "Membros",
+    "Assign to users/groups/circles" : "Assigna a utentes/grupos/tropas",
+    "Assign a user to this card…" : "Assigna utente a cust'ischeda...",
     "Upload new files" : "Carriga archìvios noos",
     "Share from Files" : "Cumpartzi dae Archìvios",
     "Add this attachment" : "Agiunghe custu alligongiadu",
@@ -202,18 +195,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Su tìtulu non podet èssere bòidu",
     "No comments yet. Begin the discussion!" : "Perunu cummentu ancora. Cumintzat sa chistionada!",
     "Failed to load comments" : "No at fatu a carrigare is cummentos",
-    "Assign a tag to this card…" : "Assigna un'eticheta a cust'ischeda...",
-    "Assign to users" : "Assigna a utentes",
-    "Assign to users/groups/circles" : "Assigna a utentes/grupos/tropas",
-    "Assign a user to this card…" : "Assigna utente a cust'ischeda...",
-    "Due date" : "Iscadèntzia",
-    "Set a due date" : "Imposta iscadèntzia",
-    "Remove due date" : "Boga s'iscadèntzia",
-    "Select Date" : "Seletziona data",
-    "Today" : "Oe",
-    "Tomorrow" : "Cras",
-    "Next week" : "Sa chida chi benit",
-    "Next month" : "Su mese chi benit",
     "Save" : "Sarva",
     "The comment cannot be empty." : "Su cummentu non podet èssere bòidu",
     "The comment cannot be longer than 1000 characters." : "Su cummentu non podet èssere prus longu de 1000 caràteres.",
@@ -221,6 +202,7 @@ OC.L10N.register(
     "Cancel reply" : "Annulla risposta",
     "Reply" : "Risponde",
     "Update" : "Agiorna",
+    "Created:" : "Creadu:",
     "Description" : "Descritzione",
     "(Unsaved)" : "(Non sarvada)",
     "(Saving…)" : "(Sarbende…)",
@@ -230,16 +212,23 @@ OC.L10N.register(
     "Add Attachment" : "Agiunghe alligongiadu",
     "Write a description …" : "Iscrie una descritzione ...",
     "Choose attachment" : "Sèbera un'alligongiadu",
-    "(group)" : "(grupu)",
-    "{count} comments, {unread} unread" : "{count} cummentos, {unread} non lèghidos",
-    "Assign to me" : "Assigna a mie",
-    "Unassign myself" : "Annulla s'assignatzione a mie",
-    "Move card" : "Tràmuda ischeda",
-    "Card details" : "Detàllios ischeda",
+    "Set a due date" : "Imposta iscadèntzia",
+    "Remove due date" : "Boga s'iscadèntzia",
+    "Completed" : "Cumpletadu",
     "Unarchive card" : "Ischeda no archiviada",
     "Archive card" : "Archìviu no archiviadu",
+    "Select Date" : "Seletziona data",
+    "Assign a tag to this card…" : "Assigna un'eticheta a cust'ischeda...",
+    "(group)" : "(grupu)",
+    "{count} comments, {unread} unread" : "{count} cummentos, {unread} non lèghidos",
+    "Card details" : "Detàllios ischeda",
+    "Assign to me" : "Assigna a mie",
+    "Unassign myself" : "Annulla s'assignatzione a mie",
+    "Mark as done" : "Marca comente cumpletadu",
+    "Move card" : "Tràmuda ischeda",
     "Delete card" : "Cantzella ischeda",
     "Move card to another board" : "Tràmuda s'ischeda a un'àtera lavagna",
+    "Select a list" : "Seletziona un'elencu",
     "List is empty" : "Sa lista est bòida",
     "Card deleted" : "Ischeda cantzellada",
     "seconds ago" : "segundos a immoe",
@@ -248,8 +237,6 @@ OC.L10N.register(
     "Shared with you" : "Cumpartzidu cun tegus",
     "Use bigger card view" : "Imprea bista cun ischedas prus mannas",
     "Show boards in calendar/tasks" : "Mustra lavagnas in calendàriu/fainas",
-    "Limit deck usage of groups" : "Mìnima s'impreu de deck de is grupos",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Su de minimare su deck at a impedire a is utentes chi non faghent parte de cuddos grupos de si creare lavagnas pròpias. Is utentes ant a èssere ancora capassos de traballare in is lavagnas chi fiant istadas cumpartzidas cun issos etotu,",
     "Board details" : "Detàllios lavagna",
     "Edit board" : "Modìfica lavagna",
     "Clone board" : "Clona lavagna",
@@ -268,10 +255,19 @@ OC.L10N.register(
     "An error occurred" : "B'at àpidu un'errore",
     "Delete the board?" : "Cheres cantzellare sa lavagna?",
     "Loading filtered view" : "Carrigamentu de sa bista cun su filtru",
+    "Today" : "Oe",
+    "Tomorrow" : "Cras",
     "No due" : "Peruna iscadèntzia",
     "Search for {searchQuery} in all boards" : "Chirca {searchQuery} in totu is lavagnas",
     "No results found" : "Perunu resurtadu agatadu",
     "{stack} in {board}" : "{stack} in {board}",
+    "Create a new card" : "Crea un'ischeda noa",
+    "Card title" : "Tìtulu ischeda",
+    "Create card" : "Crea ischeda",
+    "Creating the new card …" : "Creende s'ischeda noa ...",
+    "Card \"{card}\" was added to \"{board}\"" : "S'ischeda \"{card}\" est istada agiunta a \"{board}\"",
+    "Open card" : "Aberi ischeda",
+    "Close" : "Serra",
     "No upcoming cards" : "Peruna ischeda abarrada",
     "upcoming cards" : "ischedas abarradas",
     "Link to a board" : "Collega a una tabella",
@@ -285,6 +281,14 @@ OC.L10N.register(
     "Share with a Deck card" : "Cumpartzi cun un'ischeda deck",
     "Share {file} with a Deck card" : "Cumpartzi {file} cun un'ischeda de deck",
     "Share" : "Cumpartzi",
-    "Add a new list" : "Agiunghe un'elencu nou"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "Sa <strong>descritzione de un'ischeda</strong> in intro de s'aplicatzione Deck app est istada cambiada",
+    "Timeline" : "Fusu oràriu",
+    "Add a new list" : "Agiunghe un'elencu nou",
+    "Assign to users" : "Assigna a utentes",
+    "Due date" : "Iscadèntzia",
+    "Next week" : "Sa chida chi benit",
+    "Next month" : "Su mese chi benit",
+    "Limit deck usage of groups" : "Mìnima s'impreu de deck de is grupos",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Su de minimare su deck at a impedire a is utentes chi non faghent parte de cuddos grupos de si creare lavagnas pròpias. Is utentes ant a èssere ancora capassos de traballare in is lavagnas chi fiant istadas cumpartzidas cun issos etotu,"
 },
 "nplurals=2; plural=(n != 1);");
