@@ -63,7 +63,6 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovi prilogo {attachment} naloge {card}",
     "You have commented on card {card}" : "Vpišete opombo k nalogi {card}",
     "{user} has commented on card {card}" : "{user} vpiše opombo k nalogi {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "V programu Deck je spremenjen <strong>opis ene izmed nalog</strong>",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
@@ -110,17 +109,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Search by board title" : "Išči po imenu zbirke",
     "Select board" : "Izbor zbirke",
-    "Create a new card" : "Ustvari novo nalogo",
     "Select a board" : "Izbor zbirke",
-    "Select a list" : "Izbor seznama",
-    "Card title" : "Naslov naloge",
-    "Cancel" : "Prekliči",
-    "Creating the new card …" : "Poteka ustvarjanje nove naloge ...",
-    "Card \"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
-    "Open card" : "Odpri nalogo",
-    "Close" : "Zapri",
-    "Create card" : "Ustvari nalogo",
     "Select a card" : "Izbor naloge",
+    "Cancel" : "Prekliči",
     "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
     "Link to card" : "Poveži nalogo",
     "File already exists" : "Datoteka s tem imenom že obstaja.",
@@ -157,7 +148,7 @@ OC.L10N.register(
     "Sharing" : "Souporaba",
     "Tags" : "Oznake",
     "Deleted items" : "Izbrisani predmeti",
-    "Timeline" : "Časovnica",
+    "Activity" : "Dejavnost",
     "Deleted lists" : "Izbrisani seznami",
     "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
@@ -185,6 +176,8 @@ OC.L10N.register(
     "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
     "Board name" : "Ime zbirke",
     "Members" : "Člani",
+    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
+    "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
     "Upload new files" : "Pošlji nove datoteke",
     "Share from Files" : "Poveži iz oblaka",
     "Add this attachment" : "Dodaj prilogo",
@@ -204,18 +197,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Polje naslova ne sme biti prazno.",
     "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
     "Failed to load comments" : "Nalaganje opomb je spodletelo.",
-    "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
-    "Assign to users" : "Dodeli uporabnikom",
-    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
-    "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
-    "Due date" : "Datum preteka",
-    "Set a due date" : "Nastavi datum preteka",
-    "Remove due date" : "Odstrani datum preteka",
-    "Select Date" : "Izbor datuma",
-    "Today" : "Danes",
-    "Tomorrow" : "Jutri",
-    "Next week" : "Naslednji teden",
-    "Next month" : "Naslednji mesec",
     "Save" : "Shrani",
     "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
     "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
@@ -223,6 +204,7 @@ OC.L10N.register(
     "Cancel reply" : "Prekliči odgovor",
     "Reply" : "Odgovori",
     "Update" : "Posodobi",
+    "Created:" : "Ustvarjeno:",
     "Description" : "Opis",
     "(Unsaved)" : "(neshranjeno)",
     "(Saving…)" : "(shranjevanje ...)",
@@ -232,16 +214,25 @@ OC.L10N.register(
     "Add Attachment" : "Dodaj prilogo",
     "Write a description …" : "Vpišite opis ...",
     "Choose attachment" : "Izbor priloge",
-    "(group)" : "(skupina)",
-    "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
-    "Assign to me" : "Nalogo dodeli meni",
-    "Unassign myself" : "Odstrani me z naloge",
-    "Move card" : "Premakni nalogo",
-    "Card details" : "Podrobnosti naloge",
+    "Set a due date" : "Nastavi datum preteka",
+    "Remove due date" : "Odstrani datum preteka",
+    "Completed" : "Končano",
+    "Not completed" : "Ni končano",
     "Unarchive card" : "Povrni nalogo",
     "Archive card" : "Arhiviraj nalogo",
+    "Select Date" : "Izbor datuma",
+    "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
+    "(group)" : "(skupina)",
+    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
+    "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
+    "Card details" : "Podrobnosti naloge",
+    "Assign to me" : "Nalogo dodeli meni",
+    "Unassign myself" : "Odstrani me z naloge",
+    "Mark as done" : "Označi kot končano",
+    "Move card" : "Premakni nalogo",
     "Delete card" : "Izbriši nalogo",
     "Move card to another board" : "Premakni nalogo v drugo zbirko",
+    "Select a list" : "Izbor seznama",
     "List is empty" : "Seznam je prazen",
     "Card deleted" : "Naloga je izbrisana",
     "seconds ago" : "pred nekaj sekundami",
@@ -250,8 +241,6 @@ OC.L10N.register(
     "Shared with you" : "V souporabi z vami",
     "Use bigger card view" : "Uporabi povečan pogled nalog",
     "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
-    "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
     "Board details" : "Podrobnosti zbirke",
     "Edit board" : "Uredi zbirko",
     "Clone board" : "Kloniraj zbirko",
@@ -270,13 +259,25 @@ OC.L10N.register(
     "An error occurred" : "Prišlo je do napake.",
     "Delete the board?" : "Ali želite izbrisati zbirko?",
     "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
+    "Today" : "Danes",
+    "Tomorrow" : "Jutri",
     "No due" : "Ni datuma preteka",
     "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
     "No results found" : "Ni najdenih zadetkov",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
     "{stack} in {board}" : "{stack} v {board}",
     "Click to expand comment" : "Kliknite za razširitev opombe",
+    "Create a new card" : "Ustvari novo nalogo",
+    "Card title" : "Naslov naloge",
+    "Create card" : "Ustvari nalogo",
+    "Creating the new card …" : "Poteka ustvarjanje nove naloge ...",
+    "Card \"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
+    "Open card" : "Odpri nalogo",
+    "Close" : "Zapri",
     "No upcoming cards" : "Ni prihajajočih nalog",
     "upcoming cards" : "prihajajoče naloge",
+    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
+    "Later today – {timeLocale}" : "Danes – {timeLocale}",
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Create a card" : "Ustvari nalogo",
@@ -288,6 +289,14 @@ OC.L10N.register(
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
     "Share" : "Souporaba",
-    "Add a new list" : "Dodaj nov seznam"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "V programu Deck je spremenjen <strong>opis ene izmed nalog</strong>",
+    "Timeline" : "Časovnica",
+    "Add a new list" : "Dodaj nov seznam",
+    "Assign to users" : "Dodeli uporabnikom",
+    "Due date" : "Datum preteka",
+    "Next week" : "Naslednji teden",
+    "Next month" : "Naslednji mesec",
+    "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
