@@ -18,7 +18,6 @@ OC.L10N.register(
     "Missing a temporary folder" : "Mungon një dosje e përkohshme",
     "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
     "Cancel" : "Anullo",
-    "Close" : "Mbylleni",
     "File already exists" : "Skedari ekziston tashmë",
     "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
     "Add card" : "Shto kartë",
@@ -28,6 +27,7 @@ OC.L10N.register(
     "Details" : "Detajet",
     "Sharing" : "Ndarje",
     "Tags" : "Etiketa",
+    "Activity" : "Aktiviteti",
     "Undo" : "Ktheje pas",
     "Can edit" : "Can edit",
     "Can share" : "Mund të ndaj",
@@ -40,16 +40,15 @@ OC.L10N.register(
     "Comments" : "Komentet",
     "Modified" : "Modifikuar ",
     "Created" : "U krijua",
-    "Due date" : "Data e vendosur",
-    "Remove due date" : "Hiq datën e mbarimit",
-    "Select Date" : "Zgjidhni Datën",
-    "Today" : "Sot",
-    "Tomorrow" : "Nesër",
     "Save" : "Ruaj",
     "Reply" : "Përgjigju",
     "Update" : "Përditëso",
+    "Created:" : "Krijuar:",
     "Description" : "Përshkrim",
     "Formatting help" : "Ndihmë formatimi",
+    "Remove due date" : "Hiq datën e mbarimit",
+    "Completed" : "Të plotësuara",
+    "Select Date" : "Zgjidhni Datën",
     "(group)" : "(grup)",
     "List is empty" : "Lista është bosh",
     "seconds ago" : "sekonda më parë",
@@ -61,6 +60,10 @@ OC.L10N.register(
     "Archive board" : "Arkivo bordin",
     "No notifications" : "Asnjë njofim",
     "Delete board" : "Fshij bordin",
-    "Share" : "Shpërndaje"
+    "Today" : "Sot",
+    "Tomorrow" : "Nesër",
+    "Close" : "Mbylleni",
+    "Share" : "Shpërndaje",
+    "Due date" : "Data e vendosur"
 },
 "nplurals=2; plural=(n != 1);");
