@@ -6,11 +6,11 @@ OC.L10N.register(
     "Done" : "Done",
     "Add board" : "Dodaj tablu",
     "Cancel" : "Otkaži",
-    "Close" : "Zatvori",
     "Add card" : "Dodaj karticu",
     "Details" : "Detalji",
     "Sharing" : "Deljenje",
     "Tags" : "Oznake",
+    "Activity" : "Aktivnost",
     "Undo" : "Opozovi",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
@@ -19,14 +19,13 @@ OC.L10N.register(
     "Edit" : "Uredi",
     "Download" : "Preuzmi",
     "Attachments" : "Prilozi",
-    "Due date" : "Rok",
-    "Today" : "Danas",
     "Save" : "Sačuvaj",
     "Reply" : "Odgovori",
     "Update" : "Ažuriraj",
     "Description" : "Opis",
-    "Move card" : "Premesti karticu",
+    "Completed" : "Završeno",
     "Archive card" : "Arhiviraj karticu",
+    "Move card" : "Premesti karticu",
     "Delete card" : "Obriši karticu",
     "seconds ago" : "pre nekoliko sekundi",
     "Shared with you" : "Shared with you",
@@ -34,6 +33,9 @@ OC.L10N.register(
     "Archive board" : "Arhiviraj tablu",
     "No notifications" : "Nema obaveštenja",
     "Delete board" : "Izbriši tablu",
-    "Share" : "Podeli"
+    "Today" : "Danas",
+    "Close" : "Zatvori",
+    "Share" : "Podeli",
+    "Due date" : "Rok"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
