@@ -2,7 +2,7 @@ OC.L10N.register(
     "deck",
     {
     "You have created a new board {board}" : "Ви створили нову дошку {board}",
-    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
+    "{user} has created a new board {board}" : "{user} створив(-ла) нову дошку {board}",
     "You have deleted the board {board}" : "Ви вилучили дошку {board}",
     "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
     "You have restored the board {board}" : "Ви відновили дошку {board}",
@@ -18,19 +18,19 @@ OC.L10N.register(
     "You have unarchived the board {board}" : "Ви розархівували дошку {board}",
     "{user} has unarchived the board {before}" : "{user} розархівував дошку {перед}",
     "You have created a new list {stack} on board {board}" : "Ви створили новий список {stack} на борту {board}",
-    "{user} has created a new list {stack} on board {board}" : "{user} створив новий список {stack} на дошці {board}",
+    "{user} has created a new list {stack} on board {board}" : "{user} створив(-ла) новий список {stack} на дошці {board}",
     "You have renamed list {before} to {stack} on board {board}" : "Ви перейменували список {before} на {stack} на дошці {board}",
     "{user} has renamed list {before} to {stack} on board {board}" : "{user} змінив(-ла) назву списку {before} на {stack} на дошці {board}",
     "You have deleted list {stack} on board {board}" : "Ви видалили список {stack} на дошці {board}",
-    "{user} has deleted list {stack} on board {board}" : "{user} видалив список {stack} на дошці {board}",
+    "{user} has deleted list {stack} on board {board}" : "{user} вилучив(-ла) список {stack} на дошці {board}",
     "You have created card {card} in list {stack} on board {board}" : "Ви створили картку {card} у списку {stack} на дошці {board}",
-    "{user} has created card {card} in list {stack} on board {board}" : "{user} створив картку {card} у списку {stack} на дошці {board}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} створив(-ла) картку {card} у списку {stack} на дошці {board}",
     "You have deleted card {card} in list {stack} on board {board}" : "Ви видалили картку {card} у списку {stack} на дошці {board}",
-    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} видалив картку {card} у списку {stack} на дошці {board}",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} вилучив(-ла) картку {card} у списку {stack} на дошці {board}",
     "You have renamed the card {before} to {card}" : "Ви перейменували картку {before} на {card}",
     "{user} has renamed the card {before} to {card}" : "{user} змінив(-ла) назву картки {before} на {card}",
     "You have added a description to card {card} in list {stack} on board {board}" : "Ви додали опис картки {card} у списку {stack} на дошці {board}",
-    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} додав опис до картки {card} у списку {stack} на дошці {board}",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} додав(-ла) опис до картки {card} у списку {stack} на дошці {board}",
     "You have updated the description of card {card} in list {stack} on board {board}" : "Ви оновили опис картки {card} у списку {stack} на дошці {board}",
     "Deck" : "Колода",
     "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
@@ -65,13 +65,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
     "Search by board title" : "Шукати за назвою дошки",
     "Select board" : "Вибрати дошку",
-    "Create a new card" : "Створити нову картку",
     "Select a board" : "Вибрати дошку",
-    "Select a list" : "Виберіть список",
-    "Card title" : "Заголовок картки",
-    "Cancel" : "Скасувати",
-    "Close" : "закрити",
     "Select a card" : "Вибрати картку",
+    "Cancel" : "Скасувати",
     "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
     "Link to card" : "Прив'язати до картки",
     "File already exists" : "Файл вже існує",
@@ -86,7 +82,7 @@ OC.L10N.register(
     "Add list" : "Додати список",
     "List name" : "Назва списку",
     "Apply filter" : "Відфільтрувати",
-    "Filter by tag" : "Відібрати за позначками",
+    "Filter by tag" : "Відібрати за мітками",
     "Filter by assigned user" : "Відібрати за призначеним користувачем",
     "Unassigned" : "Скасовано призначення",
     "Filter by due date" : "Відібрати за датою завершення",
@@ -98,14 +94,15 @@ OC.L10N.register(
     "Hide archived cards" : "Приховати архівні картки",
     "Show archived cards" : "Показати архівні картки",
     "Toggle compact mode" : "Перемкнути компактний вигляд",
+    "Open details" : "Показати деталі",
     "Details" : "Деталі",
     "Loading board" : "Завантаження дошки",
     "Create a new list to add cards to this board" : "Створіть список щоб додати картки на цю дошку",
     "Board not found" : "Дошку не знайдено",
     "Sharing" : "Поділитися",
-    "Tags" : "Теги",
+    "Tags" : "Мітки",
     "Deleted items" : "Вилучені елементи",
-    "Timeline" : "Дії",
+    "Activity" : "Події",
     "Deleted lists" : "Вилучені списки",
     "Undo" : "Скасувати",
     "Deleted cards" : "Вилучені картки",
@@ -122,10 +119,12 @@ OC.L10N.register(
     "Delete list" : "Вилучити список",
     "Add a new card" : "Додати нову картку",
     "Edit" : "Редагувати",
-    "Add a new tag" : "Додати нову позначку",
+    "Add a new tag" : "Додати нову мітку",
     "title and color value must be provided" : "потрібно зазначити назву та колір",
     "Board name" : "Назва дошки",
     "Members" : "Учасники",
+    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
+    "Assign a user to this card…" : "Призначити користувачеві цю картку",
     "Upload new files" : "Додати файл",
     "Share from Files" : "Відкрити Файли",
     "Add this attachment" : "Долучити вкладення",
@@ -140,23 +139,12 @@ OC.L10N.register(
     "Modified" : "Змінено",
     "Created" : "Створено",
     "No comments yet. Begin the discussion!" : "Коментарів немає, почніть обговорення!",
-    "Assign a tag to this card…" : "Додати позначку до цієї картки",
-    "Assign to users" : "Призначити користувачам",
-    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
-    "Assign a user to this card…" : "Призначити користувачеві цю картку",
-    "Due date" : "Протягом",
-    "Set a due date" : "Встановити дату завершення",
-    "Remove due date" : "Вилучити до",
-    "Select Date" : "Вкажіть дату",
-    "Today" : "Сьогодні",
-    "Tomorrow" : "Завтра",
-    "Next week" : "Наступний тиждень",
-    "Next month" : "Наступний місяць",
     "Save" : "Зберегти",
     "In reply to" : "У відповідь",
     "Cancel reply" : "Скасувати відповідь",
     "Reply" : "Відповісти",
     "Update" : "Оновлення",
+    "Created:" : "Створено:",
     "Description" : "Опис",
     "(Unsaved)" : "(Не збережено)",
     "(Saving…)" : "(Зберігання...)",
@@ -166,16 +154,25 @@ OC.L10N.register(
     "Add Attachment" : "Долучити вкладення",
     "Write a description …" : "Додайте опис ...",
     "Choose attachment" : "Вибрати вкладення",
+    "Set a due date" : "Встановити дату завершення",
+    "Choose a date" : "Виберіть дату",
+    "Remove due date" : "Вилучити до",
+    "Completed" : "Виконано",
+    "Not completed" : "Не завершено",
+    "Unarchive card" : "Розархівувати картку",
+    "Archive card" : "Архівувати картку",
+    "Select Date" : "Вкажіть дату",
+    "Assign a tag to this card…" : "Додати мітку до цієї картки",
     "(group)" : "(група)",
     "Todo items" : "Пункти завдань",
     "Edit card title" : "Редагувати заголовок картки",
-    "Assign to me" : "Призначити мені",
-    "Move card" : "Пересунути картку",
     "Card details" : "Деталі картки",
-    "Unarchive card" : "Розархівувати картку",
-    "Archive card" : "Архівувати картку",
+    "Assign to me" : "Призначити мені",
+    "Mark as done" : "Позначити як виконане",
+    "Move card" : "Пересунути картку",
     "Delete card" : "Вилучити картку",
     "Move card to another board" : "Перемістити картку до іншої дошки",
+    "Select a list" : "Виберіть список",
     "seconds ago" : "секунд тому",
     "All boards" : "Усі дошки",
     "Archived boards" : "Архівні дошки",
@@ -183,8 +180,6 @@ OC.L10N.register(
     "Deck settings" : "Налаштування колоди",
     "Use bigger card view" : "Режим перегляду зі збільшеними картками",
     "Show boards in calendar/tasks" : "Показувати дошки в календарі та завданнях",
-    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Створення власних робочих дощок користувачам, які не входять у задані групи, буде заблоковано. Проте, такі користувачі зможуть продовжити працювати зі спільними дошками, до яких у них є доступ.",
     "Board details" : "Деталі дошки",
     "Edit board" : "Редагувати дошку",
     "Clone board" : "Копіювати дошку",
@@ -200,7 +195,12 @@ OC.L10N.register(
     "An error occurred" : "Виникла помилка",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ви впевнені, що хочете вилучити дошку {title}? Це призведе до видалення всіх даних цієї дошки, включаючи архівні картки.",
     "Delete the board?" : "Вилучити дошку?",
+    "Today" : "Сьогодні",
+    "Tomorrow" : "Завтра",
     "No due" : "Без призначеної дати",
+    "Create a new card" : "Створити нову картку",
+    "Card title" : "Заголовок картки",
+    "Close" : "закрити",
     "No upcoming cards" : "Немає майбутніх завдань",
     "upcoming cards" : "очікують на виконання",
     "Due on {date}" : "До {date}",
@@ -211,6 +211,13 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
     "Error creating the share" : "Помилка створення спільного доступу",
     "Share" : "Спільний доступ",
-    "Add a new list" : "Додати новий список"
+    "Timeline" : "Дії",
+    "Add a new list" : "Додати новий список",
+    "Assign to users" : "Призначити користувачам",
+    "Due date" : "Протягом",
+    "Next week" : "Наступний тиждень",
+    "Next month" : "Наступний місяць",
+    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Створення власних робочих дощок користувачам, які не входять у задані групи, буде заблоковано. Проте, такі користувачі зможуть продовжити працювати зі спільними дошками, до яких у них є доступ."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
