@@ -51,7 +51,6 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
     "Add board" : "Thêm dự án",
     "Cancel" : "Hủy bỏ",
-    "Close" : "Đóng",
     "File already exists" : "Tệp đã tồn tại",
     "Drop your files to upload" : "Thả tệp của bạn để tải lên",
     "Add card" : "Thêm tác vụ",
@@ -68,9 +67,11 @@ OC.L10N.register(
     "Hide archived cards" : "Ẩn tác vụ đã lưu trữ",
     "Show archived cards" : "Hiện tác vụ đã lưu trữ",
     "Toggle compact mode" : "Chuyển đổi chế độ thu gọn",
+    "Open details" : "Mở chi tiết",
     "Details" : "Thông tin",
     "Sharing" : "Đang chia sẽ",
     "Tags" : "Thẻ",
+    "Activity" : "Hoạt động",
     "Undo" : "Hoàn tác",
     "Can edit" : "Có thể chỉnh sửa",
     "Can share" : "Can share",
@@ -90,23 +91,21 @@ OC.L10N.register(
     "Comments" : "Các bình luận",
     "Modified" : "Thay đổi",
     "Created" : "Đã tạo",
-    "Due date" : "Thời hạn",
-    "Remove due date" : "Xóa thời hạn",
-    "Select Date" : "Chọn ngày",
-    "Today" : "Hôm nay",
-    "Tomorrow" : "Ngày mai",
-    "Next week" : "Tuần sau",
-    "Next month" : "Tháng sau",
     "Save" : "Lưu",
     "Reply" : "Trả l",
     "Update" : "Cập nhật",
+    "Created:" : "Đã tạo:",
     "Description" : "Mô tả",
     "Formatting help" : "Định dạng trợ giúp",
     "Edit description" : "Chỉnh sửa mô tả",
+    "Remove due date" : "Xóa thời hạn",
+    "Completed" : "Hoàn thành",
+    "Not completed" : "Chưa hoàn thành",
+    "Archive card" : "Lưu trữ thẻ",
+    "Select Date" : "Chọn ngày",
     "(group)" : "(nhóm)",
     "Assign to me" : "Phân công cho tôi",
     "Move card" : "Di chuyển thẻ",
-    "Archive card" : "Lưu trữ thẻ",
     "Delete card" : "Xoá thẻ",
     "List is empty" : "Danh sách trống",
     "seconds ago" : "vài giây trước",
@@ -121,8 +120,15 @@ OC.L10N.register(
     "Delete board" : "Xóa dự án",
     "No reminder" : "Không có nhắc hẹn",
     "An error occurred" : "Có lỗi đã xảy ra",
+    "Today" : "Hôm nay",
+    "Tomorrow" : "Ngày mai",
     "{stack} in {board}" : "{stack} trong {board}",
+    "Close" : "Đóng",
     "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin",
-    "Share" : "Chia sẻ"
+    "Error creating the share" : "Lỗi khi tạo chia sẻ",
+    "Share" : "Chia sẻ",
+    "Due date" : "Thời hạn",
+    "Next week" : "Tuần sau",
+    "Next month" : "Tháng sau"
 },
 "nplurals=1; plural=0;");
