@@ -1,31 +1,31 @@
 OC.L10N.register(
     "deck",
     {
-    "You have created a new board {board}" : "您创建了一个新面板 {board}",
-    "{user} has created a new board {board}" : "{user} 创建了一个新面板 {board}",
-    "You have deleted the board {board}" : "您删除了面板 {board}",
-    "{user} has deleted the board {board}" : "{user} 删除了面板 {board}",
-    "You have restored the board {board}" : "您恢复了面板 {board}",
-    "{user} has restored the board {board}" : "{user} 恢复了 {board}",
-    "You have shared the board {board} with {acl}" : "您已共享 {board} 给 {acl}",
-    "{user} has shared the board {board} with {acl}" : "{user} 已使用 {acl} 共享面板 {board}",
-    "You have removed {acl} from the board {board}" : "您从面板 {board} 中移除了 {acl}",
-    "{user} has removed {acl} from the board {board}" : "{user} 从面板 {board} 中移除了 {acl} ",
-    "You have renamed the board {before} to {board}" : "您将面板 {before} 重命名为 {board}",
-    "{user} has renamed the board {before} to {board}" : "{user} 将面板 {before} 重命名为 {board}",
-    "You have archived the board {board}" : "您已将面板 {board} 归档",
-    "{user} has archived the board {before}" : "{user} 已将面板 {before} 归档",
-    "You have unarchived the board {board}" : "您已将面板 {board} 撤销归档",
-    "{user} has unarchived the board {before}" : "{user} 已将面板 {before} 撤销归档",
-    "You have created a new list {stack} on board {board}" : "您在 {board} 上创建了一个新列表 {stack}面板",
-    "{user} has created a new list {stack} on board {board}" : "{user} 在 {board} 上创建了一个新列表 {stack}",
-    "You have renamed list {before} to {stack} on board {board}" : "您将面板 {board} 上的列表 {before} 重命名为 {stack}",
-    "{user} has renamed list {before} to {stack} on board {board}" : "{user} 将面板 {board} 上的列表 {before} 重命名为 {stack}",
-    "You have deleted list {stack} on board {board}" : "您删除了面板 {board} 上的列表 {stack}",
-    "{user} has deleted list {stack} on board {board}" : "{user} 删除了面板 {board} 上的列表 {stack}",
-    "You have created card {card} in list {stack} on board {board}" : "您在面板 {board} 上的列表 {stack} 中创建了卡片 {card}",
-    "{user} has created card {card} in list {stack} on board {board}" : "{user} 在面板 {board} 上的列表 {stack} 中创建了卡片 {card}",
-    "You have deleted card {card} in list {stack} on board {board}" : "您在面板 {board} 上的列表 {stack} 中删除了卡片 {card}",
+    "You have created a new board {board}" : "您创建了一个新面板{board}",
+    "{user} has created a new board {board}" : "{user} 创建了一个新面板{board}",
+    "You have deleted the board {board}" : "您删除了面板{board}",
+    "{user} has deleted the board {board}" : "{user}删除了面板{board}",
+    "You have restored the board {board}" : "您还原了面板{board}",
+    "{user} has restored the board {board}" : "{user}还原了{board}",
+    "You have shared the board {board} with {acl}" : "您已分享{board}给{acl}",
+    "{user} has shared the board {board} with {acl}" : "{user}已使用{acl}分享面板{board}",
+    "You have removed {acl} from the board {board}" : "您从面板{board}中移除了{acl}",
+    "{user} has removed {acl} from the board {board}" : "{user}从面板{board}中移除了{acl} ",
+    "You have renamed the board {before} to {board}" : "您将面板{before}重命名为{board}",
+    "{user} has renamed the board {before} to {board}" : "{user}将面板{before}重命名为{board}",
+    "You have archived the board {board}" : "您已将面板{board}归档",
+    "{user} has archived the board {before}" : "{user}已将面板{before}归档",
+    "You have unarchived the board {board}" : "您已将面板{board}取消归档",
+    "{user} has unarchived the board {before}" : "{user}已将面板{before}取消归档",
+    "You have created a new list {stack} on board {board}" : "您在{board}上创建了一个新列表{stack}面板",
+    "{user} has created a new list {stack} on board {board}" : "{user}在{board}上创建了一个新列表{stack}",
+    "You have renamed list {before} to {stack} on board {board}" : "您将面板{board}上的列表{before}重命名为{stack}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user}将面板{board}上的列表{before}重命名为{stack}",
+    "You have deleted list {stack} on board {board}" : "您删除了面板{board}上的列表{stack}",
+    "{user} has deleted list {stack} on board {board}" : "{user}删除了面板{board}上的列表{stack}",
+    "You have created card {card} in list {stack} on board {board}" : "您在面板{board}上的列表{stack}中创建了卡片{card}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user}在面板 {board}上的列表{stack}中创建了卡片{card}",
+    "You have deleted card {card} in list {stack} on board {board}" : "您在面板{board}上的列表{stack}中删除了卡片{card}",
     "{user} has deleted card {card} in list {stack} on board {board}" : "{user} 在面板 {board} 上的列表 {stack} 中删除了卡片 {card}",
     "You have renamed the card {before} to {card}" : "您将卡片 {before} 重命名为 {card}",
     "{user} has renamed the card {before} to {card}" : "{user} 将卡片 {before} 重命名为 {card}",
@@ -63,10 +63,11 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} 恢复了卡片 {card} 中的附件 {attachment}",
     "You have commented on card {card}" : "您评论了卡片 {card}",
     "{user} has commented on card {card}" : "{user} 评论了卡片 {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "看板应用中的 <strong>卡片描述</strong> 已改变",
     "Deck" : "看板",
     "Changes in the <strong>Deck app</strong>" : "<strong>看板应用</strong>中的改变",
+    "A <strong>board, list or card</strong> was changed" : "<strong>面板、列表或卡片</strong>已更新",
     "A <strong>comment</strong> was created on a card" : "卡片上创建了一个 <strong>评论</strong>",
+    "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已更新",
     "Upcoming cards" : "即将到来的卡片",
     "Load more" : "加载更多",
     "Personal" : "个人",
@@ -77,10 +78,15 @@ OC.L10N.register(
     "%s has mentioned you in a comment on \"%s\"." : "%s 在 “%s” 的评论中提到了您。",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的一条评论中提到了你",
     "The board \"%s\" has been shared with you by %s." : "面板 \"%s\" 已由 %s 共享给您。",
-    "{user} has shared {deck-board} with you." : "{user} 与你分享了 {deck-board}",
-    "Deck board" : "Deck 看板",
+    "{user} has shared {deck-board} with you." : "{user}与你分享了{deck-board}",
+    "Deck board" : "看板",
+    "Owned by %1$s" : "由 %1$s 拥有",
+    "Deck boards, cards and comments" : "看板、卡片和评论",
+    "From %1$s, in %2$s/%3$s, owned by %4$s" : "自 %1$s，位于 %2$s/%3$s，由 %4$s 拥有",
+    "Create a new deck card" : "建立新 看板 卡片",
     "Card comments" : "卡片评论",
     "%s on %s" : "%s 于 %s",
+    "Deck boards and cards" : "看板及卡片",
     "No data was provided to create an attachment." : "未能提供数据以创建附件",
     "Finished" : "已完成",
     "To review" : "待复核",
@@ -102,25 +108,19 @@ OC.L10N.register(
     "Could not write file to disk" : "无法写入文件到磁盘",
     "A PHP extension stopped the file upload" : "一个PHP扩展程序中断了文件上传。",
     "No file uploaded or file size exceeds maximum of %s" : "没有文件被上传或文件大小超出最大值 %s",
+    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此评论超过%s个字符。\n作为附件添加到名称为 %s 的卡片上。\n可通过 URL  访问：%s。",
     "Card not found" : "未找到卡片",
     "Path is already shared with this card" : "已和这张卡片分享了路径",
     "Invalid date, date format must be YYYY-MM-DD" : "无效日期，日期格式必须为 YYYY-MM-DD",
     "Personal planning and team project organization" : "个人规划和团队项目安排",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "看板应用程序是一个看板风格的管理工具，旨在为与Nextcloud集成的团队进行个人规划和项目管理。\n\n\n- 📥 添加您的任务到卡片并将之整理好\n- 📄 用Markdown写下额外的注释\n- 🔖 分配标签以更好地管理您的工作\n- 👥 与您的团队、朋友或家人分享\n- 📎 附件文件并将其嵌入到您的Markdown描述中\n- 💬 使用评论与您的团队沟通\n- ⚡ 在活动流中跟踪变更情况\n- 🚀 让您的项目井井有条",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
-    "Create a new card" : "创建一张新卡片",
     "Select a board" : "选择一个面板",
-    "Select a list" : "选择一个列表",
-    "Card title" : "卡片标题",
-    "Cancel" : "取消",
-    "Creating the new card …" : "正在创建新卡片… ",
-    "Card \"{card}\" was added to \"{board}\"" : "卡片 \"{card}\" 被添加至看板 \"{board}\"",
-    "Open card" : "打开卡片",
-    "Close" : "关闭",
-    "Create card" : "创建卡片",
     "Select a card" : "选择一张卡片",
+    "Cancel" : "取消",
     "Select the card to link to a project" : "选择要链接到一个项目的卡片",
     "Link to card" : "链接到卡片",
     "File already exists" : "文件已存在",
@@ -151,6 +151,7 @@ OC.L10N.register(
     "Toggle compact mode" : "切换简洁模式",
     "Open details" : "打开详情",
     "Details" : "详情",
+    "Currently present people" : "当前在线的人",
     "Loading board" : "正在加载面板",
     "No lists available" : "无列表可用",
     "Create a new list to add cards to this board" : "创建新列表后，即可在面板中新建卡片",
@@ -158,7 +159,7 @@ OC.L10N.register(
     "Sharing" : "正在共享",
     "Tags" : "标签",
     "Deleted items" : "已删除项",
-    "Timeline" : "时间线",
+    "Activity" : "活动",
     "Deleted lists" : "已删除的列表",
     "Undo" : "撤消",
     "Deleted cards" : "已删除的卡片",
@@ -174,10 +175,17 @@ OC.L10N.register(
     "Owner" : "所有者",
     "Delete" : "删除",
     "Failed to create share with {displayName}" : "用{displayName}创建分享失败",
-    "Transfer" : "传输",
+    "Are you sure you want to transfer the board {title} to {user}?" : "您确定要将面板 {title} 转移到 {user} 吗？",
+    "Transfer the board." : "转移面板。",
+    "Transfer" : "转移",
+    "The board has been transferred to {user}" : "面板已转移给 {user}",
+    "Failed to transfer the board to {user}" : "未能将面板转移给 {user}",
+    "Edit list title" : "编辑列表标题",
     "Archive all cards" : "归档所有卡片",
+    "Unarchive all cards" : "取消归档所有卡片",
     "Delete list" : "删除列表",
     "Archive all cards in this list" : "将该列表中的所有卡片归档",
+    "Unarchive all cards in this list" : "取消归档所有此列表中的卡片",
     "Add a new card" : "添加一张新卡片",
     "Card name" : "卡片名",
     "List deleted" : "列表被删除",
@@ -186,6 +194,8 @@ OC.L10N.register(
     "title and color value must be provided" : "必须提供标题和颜色值",
     "Board name" : "面板名称",
     "Members" : "成员",
+    "Assign to users/groups/circles" : "指派给用户/群组/圈子",
+    "Assign a user to this card…" : "为该卡片指派用户…",
     "Upload new files" : "上传新文件",
     "Share from Files" : "从文件共享",
     "Pending share" : "待分享",
@@ -206,18 +216,6 @@ OC.L10N.register(
     "The title cannot be empty." : "标题不能为空",
     "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "Failed to load comments" : "加载评论失败",
-    "Assign a tag to this card…" : "为该卡片分配标签…",
-    "Assign to users" : "指派给用户",
-    "Assign to users/groups/circles" : "指派给用户/群组/圈子",
-    "Assign a user to this card…" : "为该卡片指派用户…",
-    "Due date" : "截止日期",
-    "Set a due date" : "设置截止日期",
-    "Remove due date" : "移除截止日期",
-    "Select Date" : "选择日期",
-    "Today" : "今天",
-    "Tomorrow" : "明天",
-    "Next week" : "下周",
-    "Next month" : "下月",
     "Save" : "保存",
     "The comment cannot be empty." : "注释不能为空。",
     "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
@@ -225,6 +223,7 @@ OC.L10N.register(
     "Cancel reply" : "取消回复",
     "Reply" : "回复",
     "Update" : "更新",
+    "Created:" : "创建于：",
     "Description" : "描述",
     "(Unsaved)" : "（未保存的）",
     "(Saving…)" : "（正在保存...）",
@@ -234,33 +233,44 @@ OC.L10N.register(
     "Add Attachment" : "添加附件",
     "Write a description …" : "写一段描述",
     "Choose attachment" : "选择附件",
+    "Assign a due date to this card…" : "为此卡片指派截止日期 …",
+    "Set a due date" : "设置截止日期",
+    "Remove due date" : "移除截止日期",
+    "Completed" : "已完成",
+    "Not completed" : "没完成",
+    "Unarchive card" : "撤销对卡片的归档",
+    "Archive card" : "归档卡片",
+    "Select Date" : "选择日期",
+    "Assign a tag to this card…" : "为该卡片分配标签…",
     "(group)" : "（组）",
+    "Next week – {timeLocale}" : "下周 – {timeLocale}",
     "Todo items" : "待办事项",
     "{count} comments, {unread} unread" : "{count} 条评论，{unread} 未读",
     "Edit card title" : "编辑卡片标题",
+    "Card details" : "卡片详情",
     "Assign to me" : "指派给我",
     "Unassign myself" : "不再指派给我",
+    "Mark as done" : "标记为已完成",
     "Move card" : "移动卡片",
-    "Card details" : "卡片详情",
-    "Unarchive card" : "撤销对卡片的归档",
-    "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
     "Move card to another board" : "将卡片移到其他面板",
+    "Select a list" : "选择一个列表",
     "List is empty" : "列表为空",
     "Card deleted" : "卡片被删除",
     "seconds ago" : "几秒前",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
+    "Deck settings" : "看板设置",
     "Use bigger card view" : "使用较大的卡片视图",
+    "Show card ID badge" : "显示卡片ID序号",
     "Show boards in calendar/tasks" : "在日历/任务中显示看板",
-    "Limit deck usage of groups" : "按群组限制看板的使用权",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制看板的使用权后，不在指定群组中的用户将不能新建面板，但仍可使用已共享给他们的面板。",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
     "Clone board" : "克隆面板",
     "Unarchive board" : "撤销对面板的归档",
     "Archive board" : "归档面板",
+    "Export board" : "导出面板",
     "Turn on due date reminders" : "打开截止日期提醒",
     "Turn off due date reminders" : "关闭截止日期提醒",
     "Due date reminders" : "截止日期提醒",
@@ -272,15 +282,34 @@ OC.L10N.register(
     "Only assigned cards" : "仅限已指派的卡片",
     "No reminder" : "无提醒",
     "An error occurred" : "发生错误",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您确定要删除面板 {title} 吗？这将删除该面板的所有数据，包括已归档卡片。",
     "Delete the board?" : "是否删除面板？",
     "Loading filtered view" : "正在加载已筛选的视图",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
     "No due" : "没有到期的",
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
     "No results found" : "未找到结果",
+    "This weekend – {timeLocale}" : "本周末 – {timeLocale}",
+    "Deck board {name}\n* Last modified on {lastMod}" : "看板{name}\n* 最后修改于{lastMod}",
     "{stack} in {board}" : "{stack} 于 {board}",
     "Click to expand description" : "点击展开描述",
+    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 创建于 {created}\n* 最后修改于 {lastMod}\n* {nbAttachments} 个附件\n* {nbComments} 个评论",
+    "{nbCards} cards" : "{nbCards} 张卡片",
+    "Click to expand comment" : "点击展开评论",
+    "Create a new card" : "创建一张新卡片",
+    "Card title" : "卡片标题",
+    "Create card" : "创建卡片",
+    "Creating the new card …" : "正在创建新卡片… ",
+    "Card \"{card}\" was added to \"{board}\"" : "卡片 \"{card}\" 被添加至看板 \"{board}\"",
+    "Open card" : "打开卡片",
+    "Close" : "关闭",
     "No upcoming cards" : "没有即将到来的卡片",
     "upcoming cards" : "即将到来的卡片",
+    "New card" : "新卡片",
+    "Due on {date}" : "于 {date} 到期 ",
+    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
+    "Later today – {timeLocale}" : "今日稍晚 – {timeLocale}",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
     "Create a card" : "创建一张卡片",
@@ -292,6 +321,14 @@ OC.L10N.register(
     "Share with a Deck card" : "分享给一张看板卡片",
     "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
     "Share" : "分享",
-    "Add a new list" : "添加新列表"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "看板应用中的 <strong>卡片描述</strong> 已改变",
+    "Timeline" : "时间线",
+    "Add a new list" : "添加新列表",
+    "Assign to users" : "指派给用户",
+    "Due date" : "截止日期",
+    "Next week" : "下周",
+    "Next month" : "下月",
+    "Limit deck usage of groups" : "按群组限制看板的使用权",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制看板的使用权后，不在指定群组中的用户将不能新建面板，但仍可使用已共享给他们的面板。"
 },
 "nplurals=1; plural=0;");
