@@ -63,10 +63,13 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} 恢復了卡片 {card} 中的附件 {attachment}",
     "You have commented on card {card}" : "您意見了卡片 {card}",
     "{user} has commented on card {card}" : "{user} 意見了卡片 {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的 <strong>卡片描述</strong> 已改變",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "<strong>Deck 應用程式</strong>中的改變",
+    "A <strong>board, list or card</strong> was changed" : "<strong>面板、清單或卡片</strong>已更新",
     "A <strong>comment</strong> was created on a card" : "卡片上創建了一個 <strong>意見</strong>",
+    "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已更新",
+    "Cards due today" : "於今日到期的卡片",
+    "Cards due tomorrow" : "於明日到期的卡片",
     "Upcoming cards" : "快將到期的卡片",
     "Load more" : "載入更多",
     "Personal" : "個人",
@@ -82,6 +85,7 @@ OC.L10N.register(
     "Owned by %1$s" : "由 %1$s 擁有",
     "Deck boards, cards and comments" : "Deck 面板、卡片和評論",
     "From %1$s, in %2$s/%3$s, owned by %4$s" : "來自 %1$s，位於 %2$s/%3$s，由 %4$s 擁有",
+    "Create a new deck card" : "建立新 deck 卡片",
     "Card comments" : "卡片意見",
     "%s on %s" : "%s上%s",
     "Deck boards and cards" : "Deck 面板及卡片",
@@ -116,17 +120,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "選擇要連結到一個項目的面板",
     "Search by board title" : "通過標題搜索面板",
     "Select board" : "選擇面板",
-    "Create a new card" : "建立新卡片",
     "Select a board" : "選擇一個面板",
-    "Select a list" : "選擇一個列表",
-    "Card title" : "卡片標題",
-    "Cancel" : "取消",
-    "Creating the new card …" : "正在建立新卡片...",
-    "Card \"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
-    "Open card" : "打開卡片",
-    "Close" : "關閉",
-    "Create card" : "建立卡片",
     "Select a card" : "選擇卡片",
+    "Cancel" : "取消",
     "Select the card to link to a project" : "選擇要連結到一個項目的卡片",
     "Link to card" : "連結到卡片",
     "File already exists" : "檔案已存在",
@@ -152,9 +148,13 @@ OC.L10N.register(
     "Next 30 days" : "未來30曰",
     "No due date" : "無到期日",
     "Clear filter" : "清空過濾器",
+    "View Modes" : "檢視模式",
+    "Toggle View Modes" : "切換檢視模式",
     "Hide archived cards" : "隱藏已存檔的卡片",
     "Show archived cards" : "顯示已存檔的卡片",
     "Toggle compact mode" : "切換簡潔模式",
+    "Hide card cover images" : "隱藏卡片封面圖像",
+    "Show card cover images" : "顯示卡片封面圖像",
     "Open details" : "開啟細節",
     "Details" : "詳情",
     "Currently present people" : "目前在場人仕",
@@ -165,7 +165,7 @@ OC.L10N.register(
     "Sharing" : "正在分享",
     "Tags" : "標籤",
     "Deleted items" : "已刪除項目",
-    "Timeline" : "時間線",
+    "Activity" : "活動",
     "Deleted lists" : "已刪除的清單",
     "Undo" : "撤消",
     "Deleted cards" : "已刪除卡片",
@@ -200,6 +200,8 @@ OC.L10N.register(
     "title and color value must be provided" : "必須提供標題和顏色值",
     "Board name" : "面板名",
     "Members" : "成員",
+    "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
+    "Assign a user to this card…" : "將此卡片指派給用戶...",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從檔案進行分享",
     "Pending share" : "等待分享",
@@ -220,18 +222,6 @@ OC.L10N.register(
     "The title cannot be empty." : "標題不能為空。",
     "No comments yet. Begin the discussion!" : "尚無意見，開始討論吧！",
     "Failed to load comments" : "無法加載評論",
-    "Assign a tag to this card…" : "為該卡片分配標籤…",
-    "Assign to users" : "指派給用戶",
-    "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
-    "Assign a user to this card…" : "將此卡片指派給用戶...",
-    "Due date" : "到期日",
-    "Set a due date" : "設置到期日",
-    "Remove due date" : "移除到期日",
-    "Select Date" : "選擇日期",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
-    "Next week" : "下星期",
-    "Next month" : "下個月",
     "Save" : "保存",
     "The comment cannot be empty." : "意見不能為空。",
     "The comment cannot be longer than 1000 characters." : "意見不能超過 1000 個字符。",
@@ -239,6 +229,7 @@ OC.L10N.register(
     "Cancel reply" : "取消回覆",
     "Reply" : "回覆",
     "Update" : "更新",
+    "Created:" : "建立：",
     "Description" : "描述",
     "(Unsaved)" : "（未保存的）",
     "(Saving…)" : "（保存中...）",
@@ -248,18 +239,34 @@ OC.L10N.register(
     "Add Attachment" : "添加附件",
     "Write a description …" : "寫一段描述",
     "Choose attachment" : "選擇附件",
+    "Assign a due date to this card…" : "為此卡片指派到期日 …",
+    "Set a due date" : "設置到期日",
+    "Add due date" : "添加到期日",
+    "Choose a date" : "選擇日期",
+    "Remove due date" : "移除到期日",
+    "Completed" : "已完成",
+    "Not completed" : "未完成",
+    "Unarchive card" : "取消對卡片的封存",
+    "Archive card" : "封存卡片",
+    "Select Date" : "選擇日期",
+    "Set due date for later today" : "設定今天稍後的到期日",
+    "Set due date for tomorrow" : "設定明天的到期日",
+    "Set due date for this weekend" : "設定本週末的到期日",
+    "Set due date for next week" : "設定下星期的到期日",
+    "Assign a tag to this card…" : "為該卡片分配標籤…",
     "(group)" : "（群組）",
+    "Next week – {timeLocale}" : "下星期 – {timeLocale}",
     "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 條評論，{unread} 條未讀",
     "Edit card title" : "編輯卡片標題",
+    "Card details" : "卡片詳情",
     "Assign to me" : "指派給我",
     "Unassign myself" : "自己解除指派",
+    "Mark as done" : "標記為完成",
     "Move card" : "移動卡片",
-    "Card details" : "卡片詳情",
-    "Unarchive card" : "取消對卡片的封存",
-    "Archive card" : "封存卡片",
     "Delete card" : "刪除卡片",
     "Move card to another board" : "將卡片移到其他面板",
+    "Select a list" : "選擇一個列表",
     "List is empty" : "列表是空的",
     "Card deleted" : "卡片被刪除",
     "seconds ago" : "幾秒前",
@@ -270,8 +277,8 @@ OC.L10N.register(
     "Use bigger card view" : "使用較大的卡片視圖",
     "Show card ID badge" : "顯示卡片 ID 徽章",
     "Show boards in calendar/tasks" : "在日曆/任務中顯示面板",
-    "Limit deck usage of groups" : "限制群組使用 Deck",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將阻止不屬於這些群組的用戶創建自己的面板。用戶仍然可以在與他們的面板上工作。",
+    "Limit board creation to some groups" : "限制面板只能由某些群組創建",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組之外的用戶將無法創建自己的面板，但仍然可以在與他們共享的面板上工作。",
     "Board details" : "面板詳情",
     "Edit board" : "編輯面板",
     "Clone board" : "複製面板",
@@ -292,19 +299,33 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "你確定你要刪除 {title} 面板嗎？面板內所有數據(包括已封存的卡片)都將因此被刪除。",
     "Delete the board?" : "是否刪除面板？",
     "Loading filtered view" : "正在加載已過濾視圖",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
     "No due" : "沒有到期的",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
     "No results found" : "沒有結果",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 面板 {name}\n* 最後修改於  {lastMod}",
     "{stack} in {board}" : "{board} 中的 {stack}",
     "Click to expand description" : "點擊展開描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 創建於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
     "{nbCards} cards" : "{nbCards} 張卡片",
     "Click to expand comment" : "點擊展開評論",
+    "Create a new card" : "建立新卡片",
+    "Card title" : "卡片標題",
+    "Create card" : "建立卡片",
+    "Creating the new card …" : "正在建立新卡片...",
+    "Card \"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
+    "Open card" : "打開卡片",
+    "Close" : "關閉",
     "No upcoming cards" : "沒有快將到期的卡片",
+    "upcoming cards today" : "今天接下來的卡片",
+    "upcoming cards tomorrow" : "明天接下來的卡片",
     "upcoming cards" : "快將到期的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
+    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
+    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到面板",
     "Link to a card" : "連結到卡片",
     "Create a card" : "建立卡片",
@@ -316,6 +337,14 @@ OC.L10N.register(
     "Share with a Deck card" : "用一張 Deck 卡片進行分享 ",
     "Share {file} with a Deck card" : "用一張 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "Add a new list" : "添加一張新清單"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的 <strong>卡片描述</strong> 已改變",
+    "Timeline" : "時間線",
+    "Add a new list" : "添加一張新清單",
+    "Assign to users" : "指派給用戶",
+    "Due date" : "到期日",
+    "Next week" : "下星期",
+    "Next month" : "下個月",
+    "Limit deck usage of groups" : "限制群組使用 Deck",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將阻止不屬於這些群組的用戶創建自己的面板。用戶仍然可以在與他們的面板上工作。"
 },
 "nplurals=1; plural=0;");
