@@ -37,6 +37,10 @@ OC.L10N.register(
     "{user} has archived card {card} in list {stack} on board {board}" : "{user} 已封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
     "You have unarchived card {card} in list {stack} on board {board}" : "您已解除封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} 已解除封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
+    "You have marked the card {card} as done in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為已完成",
+    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為已完成",
+    "You have marked the card {card} as undone in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為未完成",
+    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為未完成",
     "You have removed the due date of card {card}" : "您已移除卡片 {card} 的到期日",
     "{user} has removed the due date of card {card}" : "{user} 已移除卡片 {card} 的到期日",
     "You have set the due date of card {card} to {after}" : "您已設定卡片 {card} 的到期日",
@@ -63,10 +67,13 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} 已從卡片 {card} 還原附件 {attachment}",
     "You have commented on card {card}" : "您已在卡片 {card} 上留言",
     "{user} has commented on card {card}" : "{user} 已在卡片 {card} 上留言",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的<strong>卡片描述</strong>已變更",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "<strong>Deck 應用程式</strong>中的變更",
+    "A <strong>board, list or card</strong> was changed" : "<strong>佈告欄、清單或卡片</strong>已變更",
     "A <strong>comment</strong> was created on a card" : "已在卡片上建立了<strong>留言</strong>",
+    "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已變更",
+    "Cards due today" : "卡片於今日到期",
+    "Cards due tomorrow" : "卡片於明日到期",
     "Upcoming cards" : "接下來的卡片",
     "Load more" : "載入更多",
     "Personal" : "個人",
@@ -82,6 +89,7 @@ OC.L10N.register(
     "Owned by %1$s" : "由 %1$s 擁有",
     "Deck boards, cards and comments" : "Deck 看板、卡片與評論",
     "From %1$s, in %2$s/%3$s, owned by %4$s" : "來自 %1$s，在 %2$s/%3$s，由 %4$s 擁有",
+    "Create a new deck card" : "建立新 deck 卡片",
     "Card comments" : "卡片留言",
     "%s on %s" : "%s 在 %s",
     "Deck boards and cards" : "Deck 看板與卡片",
@@ -116,17 +124,9 @@ OC.L10N.register(
     "Select the board to link to a project" : "選取要連結到專案的佈告欄",
     "Search by board title" : "按佈告欄標題搜尋",
     "Select board" : "選取佈告欄",
-    "Create a new card" : "建立新卡片",
     "Select a board" : "選取佈告欄",
-    "Select a list" : "選取列表",
-    "Card title" : "卡片標題",
-    "Cancel" : "取消",
-    "Creating the new card …" : "正在建立新卡片……",
-    "Card \"{card}\" was added to \"{board}\"" : "卡片「{card}」已新增至「{board}」",
-    "Open card" : "開啟卡片",
-    "Close" : "關閉",
-    "Create card" : "建立卡片",
     "Select a card" : "選取卡片",
+    "Cancel" : "取消",
     "Select the card to link to a project" : "選取要連結到專案的卡片",
     "Link to card" : "連結到卡片",
     "File already exists" : "檔案已存在",
@@ -152,9 +152,13 @@ OC.L10N.register(
     "Next 30 days" : "接下來30天",
     "No due date" : "無到期日",
     "Clear filter" : "清除過濾條件",
+    "View Modes" : "檢視模式",
+    "Toggle View Modes" : "切換檢視模式",
     "Hide archived cards" : "隱藏已封存的卡片",
     "Show archived cards" : "顯示已封存的卡片",
     "Toggle compact mode" : "切換簡潔模式",
+    "Hide card cover images" : "隱藏卡片封面影像",
+    "Show card cover images" : "顯示卡片封面影像",
     "Open details" : "開啟細節",
     "Details" : "詳細資料",
     "Currently present people" : "目前在場夥伴",
@@ -165,7 +169,7 @@ OC.L10N.register(
     "Sharing" : "分享",
     "Tags" : "標籤",
     "Deleted items" : "刪除的項目",
-    "Timeline" : "時間軸",
+    "Activity" : "活動",
     "Deleted lists" : "已刪除的列表",
     "Undo" : "復原",
     "Deleted cards" : "已刪除的卡片",
@@ -200,6 +204,8 @@ OC.L10N.register(
     "title and color value must be provided" : "必須提供標題與顏色的值",
     "Board name" : "佈告欄名稱",
     "Members" : "成員",
+    "Assign to users/groups/circles" : "分配給使用者／群組／小圈圈",
+    "Assign a user to this card…" : "分配使用者到此卡片……",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從「檔案」分享",
     "Pending share" : "待分享",
@@ -220,18 +226,6 @@ OC.L10N.register(
     "The title cannot be empty." : "標題不能為空",
     "No comments yet. Begin the discussion!" : "暫無留言。開始討論吧！",
     "Failed to load comments" : "載入留言失敗",
-    "Assign a tag to this card…" : "分配標籤到此卡片……",
-    "Assign to users" : "分配給使用者",
-    "Assign to users/groups/circles" : "分配給使用者／群組／小圈圈",
-    "Assign a user to this card…" : "分配使用者到此卡片……",
-    "Due date" : "到期日",
-    "Set a due date" : "設定到期日",
-    "Remove due date" : "移除到期日",
-    "Select Date" : "選擇日期",
-    "Today" : "今天",
-    "Tomorrow" : "明天",
-    "Next week" : "下週",
-    "Next month" : "下個月",
     "Save" : "儲存",
     "The comment cannot be empty." : "留言不能為空。",
     "The comment cannot be longer than 1000 characters." : "留言不能多於 1000 個字元。",
@@ -239,6 +233,7 @@ OC.L10N.register(
     "Cancel reply" : "取消回覆",
     "Reply" : "回覆",
     "Update" : "更新",
+    "Created:" : "建立：",
     "Description" : "描述",
     "(Unsaved)" : "（未儲存）",
     "(Saving…)" : "（正在儲存……）",
@@ -248,18 +243,37 @@ OC.L10N.register(
     "Add Attachment" : "新增附件",
     "Write a description …" : "編寫描述……",
     "Choose attachment" : "選擇附件",
+    "Assign a due date to this card…" : "為此卡片指派到期日……",
+    "Set a due date" : "設定到期日",
+    "Add due date" : "新增到期日",
+    "Choose a date" : "選擇日期",
+    "Remove due date" : "移除到期日",
+    "Completed" : "已完成",
+    "Due at:" : "到期於：",
+    "Not completed" : "未完成",
+    "Unarchive card" : "解除封存卡片",
+    "Archive card" : "封存卡片",
+    "Select Date" : "選擇日期",
+    "Set due date for later today" : "設定今天稍後的到期日",
+    "Set due date for tomorrow" : "設定明天的到期日",
+    "Set due date for this weekend" : "設定本週末的到期日",
+    "Set due date for next week" : "設定下週的到期日",
+    "Assign a tag to this card…" : "分配標籤到此卡片……",
+    "Create a new tag:" : "建立新標籤：",
     "(group)" : "（群組）",
+    "Next week – {timeLocale}" : "下週 – {timeLocale}",
     "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 則留言，{unread} 則未讀",
     "Edit card title" : "編輯卡片標題",
+    "Card details" : "卡片詳細資訊",
     "Assign to me" : "分配給我",
     "Unassign myself" : "取消分配給我",
+    "Mark as not done" : "標記為未完成",
+    "Mark as done" : "標記為完成",
     "Move card" : "移動卡片",
-    "Card details" : "卡片詳細資訊",
-    "Unarchive card" : "解除封存卡片",
-    "Archive card" : "封存卡片",
     "Delete card" : "刪除卡片",
     "Move card to another board" : "將卡片移動到其他佈告欄",
+    "Select a list" : "選取列表",
     "List is empty" : "清單為空",
     "Card deleted" : "卡片已刪除",
     "seconds ago" : "幾秒前",
@@ -270,8 +284,8 @@ OC.L10N.register(
     "Use bigger card view" : "使用較大的卡片檢視",
     "Show card ID badge" : "顯示卡片 ID 徽章",
     "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
-    "Limit deck usage of groups" : "限制群組的 Deck 使用",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將會阻止不屬於這些群組的使用者建立自己的佈告欄。使用者仍然可以在與他們分享的佈告欄上工作。",
+    "Limit board creation to some groups" : "限制僅某些群組可建立看板",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
     "Board details" : "佈告欄詳細資訊",
     "Edit board" : "編輯佈告欄",
     "Clone board" : "再製佈告欄",
@@ -292,19 +306,33 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料，包含封存的卡片。",
     "Delete the board?" : "刪除佈告欄？",
     "Loading filtered view" : "正在載入過濾的檢視",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
     "No due" : "無到期日",
     "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
     "No results found" : "找不到結果",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 看板 {name}\n* 最後修改於 {lastMod}",
     "{stack} in {board}" : "{stack} 於 {board}",
     "Click to expand description" : "點擊展開描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 建立於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
     "{nbCards} cards" : "{nbCards} 張卡片",
     "Click to expand comment" : "點擊展開留言",
+    "Create a new card" : "建立新卡片",
+    "Card title" : "卡片標題",
+    "Create card" : "建立卡片",
+    "Creating the new card …" : "正在建立新卡片……",
+    "Card \"{card}\" was added to \"{board}\"" : "卡片「{card}」已新增至「{board}」",
+    "Open card" : "開啟卡片",
+    "Close" : "關閉",
     "No upcoming cards" : "無接下來的卡片",
+    "upcoming cards today" : "今天接下來的卡片",
+    "upcoming cards tomorrow" : "明天接下來的卡片",
     "upcoming cards" : "接下來的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
+    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
+    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到佈告欄",
     "Link to a card" : "連結到卡片",
     "Create a card" : "建立卡片",
@@ -316,6 +344,14 @@ OC.L10N.register(
     "Share with a Deck card" : "與 Deck 卡片分享",
     "Share {file} with a Deck card" : "與 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "Add a new list" : "新增列表"
+    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的<strong>卡片描述</strong>已變更",
+    "Timeline" : "時間軸",
+    "Add a new list" : "新增列表",
+    "Assign to users" : "分配給使用者",
+    "Due date" : "到期日",
+    "Next week" : "下週",
+    "Next month" : "下個月",
+    "Limit deck usage of groups" : "限制群組的 Deck 使用",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將會阻止不屬於這些群組的使用者建立自己的佈告欄。使用者仍然可以在與他們分享的佈告欄上工作。"
 },
 "nplurals=1; plural=0;");
